error property
For failed actions, more information on the cause of the failure. Consider using the Error type.
Implementation
SchemaThing? error;
For failed actions, more information on the cause of the failure. Consider using the Error type.
SchemaThing? error;