SchemaAggregateOffer class

//purl.org/goodrelations/v1#Sell if businessFunction is not explicitly defined. See https://schema.org/AggregateOffer

Inheritance

Constructors

SchemaAggregateOffer({dynamic acceptedPaymentMethod, SchemaOffer? addOn, SchemaPropertyValue? additionalProperty, String? additionalType, SchemaQuantitativeValue? advanceBookingRequirement, SchemaAggregateRating? aggregateRating, String? alternateName, dynamic areaServed, String? asin, SchemaItemAvailability? availability, String? availabilityEnds, String? availabilityStarts, SchemaPlace? availableAtOrFrom, SchemaDeliveryMethod? availableDeliveryMethod, SchemaBusinessFunction? businessFunction, dynamic category, String? checkoutPageURLTemplate, SchemaQuantitativeValue? deliveryLeadTime, dynamic description, String? disambiguatingDescription, SchemaBusinessEntityType? eligibleCustomerType, SchemaQuantitativeValue? eligibleDuration, SchemaQuantitativeValue? eligibleQuantity, dynamic eligibleRegion, SchemaPriceSpecification? eligibleTransactionVolume, String? gtin, String? gtin12, String? gtin13, String? gtin14, String? gtin8, SchemaAdultOrientedEnumeration? hasAdultConsideration, String? hasGS1DigitalLink, SchemaQuantitativeValue? hasMeasurement, SchemaMerchantReturnPolicy? hasMerchantReturnPolicy, dynamic identifier, dynamic image, SchemaTypeAndQuantityNode? includesObject, dynamic ineligibleRegion, SchemaQuantitativeValue? inventoryLevel, bool? isFamilyFriendly, SchemaOfferItemCondition? itemCondition, dynamic itemOffered, dynamic leaseLength, dynamic mainEntityOfPage, String? mobileUrl, String? mpn, String? name, dynamic offeredBy, dynamic owner, SchemaAction? potentialAction, dynamic price, String? priceCurrency, SchemaPriceSpecification? priceSpecification, String? priceValidUntil, SchemaReview? review, SchemaReview? reviews, String? sameAs, dynamic seller, String? serialNumber, SchemaOfferShippingDetails? shippingDetails, String? sku, dynamic subjectOf, String? url, SchemaMemberProgramTier? validForMemberTier, String? validFrom, String? validThrough, SchemaWarrantyPromise? warranty, dynamic highPrice, dynamic lowPrice, int? offerCount, dynamic offers})
Create a new instance of SchemaAggregateOffer

Properties

acceptedPaymentMethod ↔ dynamic
The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.
getter/setter pairinherited
additionalProperty SchemaPropertyValue?
//schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
getter/setter pairinherited
additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
addOn SchemaOffer?
An additional offer that can only be obtained in combination with the first base offer (e.g. supplements and extensions that are available for a surcharge).
getter/setter pairinherited
advanceBookingRequirement SchemaQuantitativeValue?
The amount of time that is required between accepting the offer and the actual usage of the resource or service.
getter/setter pairinherited
aggregateRating SchemaAggregateRating?
The overall rating, based on a collection of reviews or ratings, of the item.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
areaServed ↔ dynamic
The geographic area where a service or offered item is provided.
getter/setter pairinherited
asin String?
//en.wikipedia.org/wiki/Amazon_Standard_Identification_Number)'s article).
getter/setter pairinherited
availability SchemaItemAvailability?
The availability of this item—for example In stock, Out of stock, Pre-order, etc.
getter/setter pairinherited
availabilityEnds String?
The end of the availability of the product or service included in the offer.
getter/setter pairinherited
availabilityStarts String?
The beginning of the availability of the product or service included in the offer.
getter/setter pairinherited
availableAtOrFrom SchemaPlace?
The place(s) from which the offer can be obtained (e.g. store locations).
getter/setter pairinherited
availableDeliveryMethod SchemaDeliveryMethod?
The delivery method(s) available for this offer.
getter/setter pairinherited
businessFunction SchemaBusinessFunction?
//purl.org/goodrelations/v1#Sell.
getter/setter pairinherited
category ↔ dynamic
A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
getter/setter pairinherited
checkoutPageURLTemplate String?
A URL template (RFC 6570) for a checkout page for an offer. This approach allows merchants to specify a URL for online checkout of the offered product, by interpolating parameters such as the logged in user ID, product ID, quantity, discount code etc. Parameter naming and standardization are not specified here.
getter/setter pairinherited
deliveryLeadTime SchemaQuantitativeValue?
The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
eligibleCustomerType SchemaBusinessEntityType?
The type(s) of customers for which the given offer is valid.
getter/setter pairinherited
eligibleDuration SchemaQuantitativeValue?
The duration for which the given offer is valid.
getter/setter pairinherited
eligibleQuantity SchemaQuantitativeValue?
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
getter/setter pairinherited
eligibleRegion ↔ dynamic
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also SchemaineligibleRegion.
getter/setter pairinherited
eligibleTransactionVolume SchemaPriceSpecification?
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
getter/setter pairinherited
gtin String?
//www.gs1.org/standards/Digital-Link/) expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the SchemahasGS1DigitalLink attribute.
getter/setter pairinherited
gtin12 String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
gtin13 String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
gtin14 String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
gtin8 String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
hasAdultConsideration SchemaAdultOrientedEnumeration?
Used to tag an item to be intended or suitable for consumption or use by adults only.
getter/setter pairinherited
  • A Digital Link that contains a serial number (AI 21) should only be present on instances of [SchemaIndividualProduct]
  • A Digital Link that contains a lot number (AI 10) should be annotated as [SchemaSomeProducts] if only products from that lot are sold, or [SchemaIndividualProduct] if there is only a specific product.
  • A Digital Link that contains a global model number (AI 8013) should be attached to a [SchemaProduct] or a [SchemaProductModel].
  • getter/setter pairinherited
    hashCode int
    The hash code for this object.
    no setterinherited
    hasMeasurement SchemaQuantitativeValue?
    A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.
    getter/setter pairinherited
    hasMerchantReturnPolicy SchemaMerchantReturnPolicy?
    Specifies a MerchantReturnPolicy that may be applicable.
    getter/setter pairinherited
    highPrice ↔ dynamic
    \n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
    getter/setter pair
    identifier ↔ dynamic
    The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
    getter/setter pairinherited
    image ↔ dynamic
    An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
    getter/setter pairinherited
    includesObject SchemaTypeAndQuantityNode?
    This links to a node or nodes indicating the exact quantity of the products included in an SchemaOffer or SchemaProductCollection.
    getter/setter pairinherited
    ineligibleRegion ↔ dynamic
    The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also SchemaeligibleRegion.
    getter/setter pairinherited
    inventoryLevel SchemaQuantitativeValue?
    The current approximate inventory level for the item or items.
    getter/setter pairinherited
    isFamilyFriendly bool?
    Indicates whether this content is family friendly.
    getter/setter pairinherited
    itemCondition SchemaOfferItemCondition?
    A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.
    getter/setter pairinherited
    itemOffered ↔ dynamic
    An item being offered (or demanded). The transactional nature of the offer or demand is documented using SchemabusinessFunction, e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
    getter/setter pairinherited
    leaseLength ↔ dynamic
    Length of the lease for some SchemaAccommodation, either particular to some SchemaOffer or in some cases intrinsic to the property.
    getter/setter pairinherited
    lowPrice ↔ dynamic
    \n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
    getter/setter pair
    mainEntityOfPage ↔ dynamic
    Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
    getter/setter pairinherited
    mobileUrl String?
    //en.wikipedia.org/wiki/Responsive_web_design) in which content can be flexibly adapted to a wide range of browsing environments. Pages and sites referenced with the long-established Schemaurl property should ideally also be usable on a wide variety of devices, including mobile phones. In most cases, it would be pointless and counter productive to attempt to update all Schemaurl markup to use SchemamobileUrl for more mobile-oriented pages. The property is intended for the case when items (primarily SchemaProduct and SchemaOffer) have extra URLs hosted on an additional "mobile site" alongside the main one. It should not be taken as an endorsement of this publication style.
    getter/setter pairinherited
    mpn String?
    The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
    getter/setter pairinherited
    name String?
    The name of the item.
    getter/setter pairinherited
    offerCount int?
    The number of offers for the product.
    getter/setter pair
    offeredBy ↔ dynamic
    A pointer to the organization or person making the offer.
    getter/setter pairinherited
    offers ↔ dynamic
    An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use SchemabusinessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
    getter/setter pair
    owner ↔ dynamic
    A person or organization who owns this Thing.
    getter/setter pairinherited
    potentialAction SchemaAction?
    Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
    getter/setter pairinherited
    price ↔ dynamic
    //www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and Microdata syntax allow the use of a "content=" attribute for publishing simple machine-readable values alongside more human-friendly formatting.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.
    getter/setter pairinherited
    priceCurrency String?
    //en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".
    getter/setter pairinherited
    priceSpecification SchemaPriceSpecification?
    One or more detailed price specifications, indicating the unit price and delivery or payment charges.
    getter/setter pairinherited
    priceValidUntil String?
    The date after which the price is no longer available.
    getter/setter pairinherited
    review SchemaReview?
    A review of the item.
    getter/setter pairinherited
    reviews SchemaReview?
    Review of the item.
    getter/setter pairinherited
    runtimeType Type
    A representation of the runtime type of the object.
    no setterinherited
    sameAs String?
    URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
    getter/setter pairinherited
    seller ↔ dynamic
    An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
    getter/setter pairinherited
    serialNumber String?
    The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.
    getter/setter pairinherited
    shippingDetails SchemaOfferShippingDetails?
    Indicates information about the shipping policies and options associated with an SchemaOffer.
    getter/setter pairinherited
    sku String?
    The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
    getter/setter pairinherited
    subjectOf ↔ dynamic
    A CreativeWork or Event about this Thing.
    getter/setter pairinherited
    url String?
    URL of the item.
    getter/setter pairinherited
    validForMemberTier SchemaMemberProgramTier?
    The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.
    getter/setter pairinherited
    validFrom String?
    The date when the item becomes valid.
    getter/setter pairinherited
    validThrough String?
    The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.
    getter/setter pairinherited
    warranty SchemaWarrantyPromise?
    The warranty promise(s) included in the offer.
    getter/setter pairinherited

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJsonLd() Map<String, dynamic>
    Serialize SchemaAggregateOffer to JSON-LD
    override
    toString() String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) bool
    The equality operator.
    inherited