SchemaAggregateRating class

The average rating based on multiple ratings or reviews. See https://schema.org/AggregateRating

Inheritance
Implementers

Constructors

SchemaAggregateRating({String? additionalType, String? alternateName, dynamic author, dynamic bestRating, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? ratingExplanation, dynamic ratingValue, dynamic reviewAspect, String? sameAs, dynamic subjectOf, String? url, dynamic worstRating, SchemaThing? itemReviewed, int? ratingCount, int? reviewCount})
Create a new instance of SchemaAggregateRating

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
author ↔ dynamic
The author of this content or rating. Please note that author is special in that HTML 5 provides a special mechanism for indicating authorship via the rel tag. That is equivalent to this and may be used interchangeably.
getter/setter pairinherited
bestRating ↔ dynamic
The highest value allowed in this rating system.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
itemReviewed SchemaThing?
The item that is being reviewed/rated.
getter/setter pair
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
ratingCount int?
The count of total number of ratings.
getter/setter pair
ratingExplanation String?
A short explanation (e.g. one to two sentences) providing background context and other information that led to the conclusion expressed in the rating. This is particularly applicable to ratings associated with "fact check" markup using SchemaClaimReview.
getter/setter pairinherited
ratingValue ↔ dynamic
\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
getter/setter pairinherited
reviewAspect ↔ dynamic
This Review or Rating is relevant to this part or facet of the itemReviewed.
getter/setter pairinherited
reviewCount int?
The count of total number of reviews.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited
worstRating ↔ dynamic
The lowest value allowed in this rating system.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaAggregateRating to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited