blogPosts property

  1. @Deprecated('Use [blogPost]. See https://schema.org/blogPosts')
SchemaBlogPosting? blogPosts
getter/setter pair

Indicates a post that is part of a SchemaBlog. Note that historically, what we term a "Blog" was once known as a "weblog", and that what we term a "BlogPosting" is now often colloquially referred to as a "blog".

Implementation

@Deprecated('Use [blogPost]. See https://schema.org/blogPosts')
SchemaBlogPosting? blogPosts;