area property
The area within which users can expect to reach the broadcast service.
Implementation
@Deprecated('Use [serviceArea]. See https://schema.org/area')
SchemaPlace? area;
The area within which users can expect to reach the broadcast service.
@Deprecated('Use [serviceArea]. See https://schema.org/area')
SchemaPlace? area;