SchemaBusTrip class

A trip on a commercial bus line. See https://schema.org/BusTrip

Inheritance

Constructors

SchemaBusTrip({String? additionalType, String? alternateName, String? arrivalTime, String? departureTime, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic itinerary, dynamic mainEntityOfPage, String? name, dynamic offers, dynamic owner, SchemaTrip? partOfTrip, SchemaAction? potentialAction, dynamic provider, String? sameAs, SchemaTrip? subTrip, dynamic subjectOf, SchemaPlace? tripOrigin, String? url, dynamic arrivalBusStop, String? busName, String? busNumber, dynamic departureBusStop})
Create a new instance of SchemaBusTrip

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
arrivalBusStop ↔ dynamic
The stop or station from which the bus arrives.
getter/setter pair
arrivalTime String?
The expected arrival time.
getter/setter pairinherited
busName String?
The name of the bus (e.g. Bolt Express).
getter/setter pair
busNumber String?
The unique identifier for the bus.
getter/setter pair
departureBusStop ↔ dynamic
The stop or station from which the bus departs.
getter/setter pair
departureTime String?
The expected departure time.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
itinerary ↔ dynamic
Destination(s) ( SchemaPlace ) that make up a trip. For a trip where destination order is important use SchemaItemList to specify that order (see examples).
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
offers ↔ dynamic
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use SchemabusinessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
partOfTrip SchemaTrip?
Identifies that this SchemaTrip is a subTrip of another Trip. For example Day 1, Day 2, etc. of a multi-day trip.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
provider ↔ dynamic
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
subTrip SchemaTrip?
Identifies a SchemaTrip that is a subTrip of this Trip. For example Day 1, Day 2, etc. of a multi-day trip.
getter/setter pairinherited
tripOrigin SchemaPlace?
The location of origin of the trip, prior to any destination(s).
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaBusTrip to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited