SchemaCampground class
//en.wikipedia.org/wiki/Campsite)).\n\n
See also the dedicated document on the use of schema.org for marking up hotels and other forms of accommodations. See https://schema.org/Campground
- Inheritance
-
- Object
- SchemaThing
- SchemaPlace
- SchemaCivicStructure
- SchemaCampground
- Implemented types
Constructors
- SchemaCampground({SchemaPropertyValue? additionalProperty, String? additionalType, dynamic address, SchemaAggregateRating? aggregateRating, String? alternateName, SchemaLocationFeatureSpecification? amenityFeature, String? branchCode, SchemaPlace? containedIn, SchemaPlace? containedInPlace, SchemaPlace? containsPlace, dynamic description, String? disambiguatingDescription, SchemaEvent? event, SchemaEvent? events, String? faxNumber, dynamic geo, dynamic geoContains, dynamic geoCoveredBy, dynamic geoCovers, dynamic geoCrosses, dynamic geoDisjoint, dynamic geoEquals, dynamic geoIntersects, dynamic geoOverlaps, dynamic geoTouches, dynamic geoWithin, String? globalLocationNumber, SchemaCertification? hasCertification, bool? hasDriveThroughService, String? hasGS1DigitalLink, dynamic hasMap, dynamic identifier, dynamic image, bool? isAccessibleForFree, String? isicV4, dynamic keywords, dynamic latitude, dynamic logo, dynamic longitude, dynamic mainEntityOfPage, String? map, String? maps, int? maximumAttendeeCapacity, String? name, String? openingHours, SchemaOpeningHoursSpecification? openingHoursSpecification, dynamic owner, dynamic photo, dynamic photos, SchemaAction? potentialAction, bool? publicAccess, SchemaReview? review, SchemaReview? reviews, String? sameAs, String? slogan, bool? smokingAllowed, SchemaOpeningHoursSpecification? specialOpeningHoursSpecification, dynamic subjectOf, String? telephone, String? tourBookingPage, String? url, SchemaAudience? audience, dynamic availableLanguage, String? checkinTime, String? checkoutTime, dynamic numberOfRooms, dynamic petsAllowed, SchemaRating? starRating, SchemaOrganization? branchOf, String? currenciesAccepted, String? floorLevel, String? paymentAccepted, String? priceRange, dynamic acceptedPaymentMethod, dynamic actionableFeedbackPolicy, SchemaInteractionCounter? agentInteractionStatistic, SchemaPerson? alumni, dynamic areaServed, String? award, String? awards, dynamic brand, SchemaCertification? companyRegistration, SchemaContactPoint? contactPoint, SchemaContactPoint? contactPoints, dynamic correctionsPolicy, SchemaOrganization? department, String? dissolutionDate, dynamic diversityPolicy, dynamic diversityStaffingReport, String? duns, String? email, SchemaPerson? employee, SchemaPerson? employees, dynamic ethicsPolicy, dynamic founder, SchemaPerson? founders, String? foundingDate, SchemaPlace? foundingLocation, dynamic funder, SchemaGrant? funding, SchemaCredential? hasCredential, SchemaMemberProgram? hasMemberProgram, SchemaMerchantReturnPolicy? hasMerchantReturnPolicy, SchemaOfferCatalog? hasOfferCatalog, SchemaPlace? hasPOS, SchemaShippingService? hasShippingService, SchemaInteractionCounter? interactionStatistic, String? iso6523Code, dynamic knowsAbout, dynamic knowsLanguage, SchemaPostalAddress? legalAddress, String? legalName, SchemaPerson? legalRepresentative, String? leiCode, dynamic location, SchemaOffer? makesOffer, dynamic member, dynamic memberOf, dynamic members, String? naics, SchemaNonprofitType? nonprofitStatus, SchemaQuantitativeValue? numberOfEmployees, dynamic ownershipFundingInfo, SchemaThing? owns, SchemaOrganization? parentOrganization, dynamic publishingPrinciples, SchemaDemand? seeks, dynamic serviceArea, dynamic skills, dynamic sponsor, SchemaOrganization? subOrganization, String? taxID, dynamic unnamedSourcesPolicy, String? vatID})
- Create a new instance of SchemaCampground
Properties
- acceptedPaymentMethod ↔ dynamic
-
The payment method(s) that are accepted in general by an organization, or
for some specific demand or offer.
getter/setter pairoverride
- actionableFeedbackPolicy ↔ dynamic
-
For a SchemaNewsMediaOrganization or other news-related
SchemaOrganization, a statement about public engagement activities (for
news media, the newsroom’s), including involving the public - digitally
or otherwise -- in coverage decisions, reporting and activities after
publication.
getter/setter pairoverride
- additionalProperty ↔ SchemaPropertyValue?
-
//schema.org/gtin13, ...) will typically expect such data to be provided
using those properties, rather than using the generic property/value
mechanism.
getter/setter pairinherited
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- address ↔ dynamic
-
Physical address of the item.
getter/setter pairinherited
- agentInteractionStatistic ↔ SchemaInteractionCounter?
-
The number of completed interactions for this entity, in a particular
role (the 'agent'), in a particular action (indicated in the statistic),
and in a particular context (i.e. interactionService).
getter/setter pairoverride
- aggregateRating ↔ SchemaAggregateRating?
-
The overall rating, based on a collection of reviews or ratings, of the
item.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- alumni ↔ SchemaPerson?
-
Alumni of an organization.
getter/setter pairoverride
- amenityFeature ↔ SchemaLocationFeatureSpecification?
-
An amenity feature (e.g. a characteristic or service) of the
Accommodation. This generic property does not make a statement about
whether the feature is included in an offer for the main accommodation or
available at extra costs.
getter/setter pairinherited
- areaServed ↔ dynamic
-
The geographic area where a service or offered item is provided.
getter/setter pairoverride
- audience ↔ SchemaAudience?
-
An intended audience, i.e. a group for whom something was created.
getter/setter pairoverride
- availableLanguage ↔ dynamic
-
//tools.ietf.org/html/bcp47). See also
SchemainLanguage.getter/setter pairoverride - award ↔ String?
-
An award won by or for this item.
getter/setter pairoverride
- awards ↔ String?
-
Awards won by or for this item.
getter/setter pairoverride
- branchCode ↔ String?
-
//www.starbucks.co.uk/store-locator/etc/detail/3047 the code "3047" is a
branchCode for a particular branch.
getter/setter pairinherited
- branchOf ↔ SchemaOrganization?
-
The larger organization that this local business is a branch of, if any.
Not to be confused with (anatomical)
Schemabranch.getter/setter pairoverride - brand ↔ dynamic
-
The brand(s) associated with a product or service, or the brand(s)
maintained by an organization or business person.
getter/setter pairoverride
- checkinTime ↔ String?
-
The earliest someone may check into a lodging establishment.
getter/setter pairoverride
- checkoutTime ↔ String?
-
The latest someone may check out of a lodging establishment.
getter/setter pairoverride
- companyRegistration ↔ SchemaCertification?
-
The official registration information of a business including the
organization that issued it such as Company House or Chamber of Commerce
in form of a Certification.
getter/setter pairoverride
- contactPoint ↔ SchemaContactPoint?
-
A contact point for a person or organization.
getter/setter pairoverride
- contactPoints ↔ SchemaContactPoint?
-
A contact point for a person or organization.
getter/setter pairoverride
- containedIn ↔ SchemaPlace?
-
The basic containment relation between a place and one that contains it.
getter/setter pairinherited
- containedInPlace ↔ SchemaPlace?
-
The basic containment relation between a place and one that contains it.
getter/setter pairinherited
- containsPlace ↔ SchemaPlace?
-
The basic containment relation between a place and another that it
contains.
getter/setter pairinherited
- correctionsPolicy ↔ dynamic
-
For an SchemaOrganization (e.g. SchemaNewsMediaOrganization), a
statement describing (in news media, the newsroom’s) disclosure and
correction policy for errors.
getter/setter pairoverride
- currenciesAccepted ↔ String?
-
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other
currency types, e.g. "Ithaca HOUR".
getter/setter pairoverride
- department ↔ SchemaOrganization?
-
a store with a pharmacy, or a bakery with a cafe.
getter/setter pairoverride
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- dissolutionDate ↔ String?
-
The date that this organization was dissolved.
getter/setter pairoverride
- diversityPolicy ↔ dynamic
-
Statement on diversity policy by an SchemaOrganization e.g. a
SchemaNewsMediaOrganization. For a SchemaNewsMediaOrganization, a
statement describing the newsroom’s diversity policy on both staffing and
sources, typically providing staffing data.
getter/setter pairoverride
- diversityStaffingReport ↔ dynamic
-
For an SchemaOrganization (often but not necessarily a
SchemaNewsMediaOrganization), a report on staffing diversity issues. In
a news context this might be for example ASNE or RTDNA (US) reports, or
self-reported.
getter/setter pairoverride
- duns ↔ String?
-
The Dun & Bradstreet DUNS number for identifying an organization or
business person.
getter/setter pairoverride
- email ↔ String?
-
Email address.
getter/setter pairoverride
- employee ↔ SchemaPerson?
-
Someone working for this organization.
getter/setter pairoverride
- employees ↔ SchemaPerson?
-
People working for this organization.
getter/setter pairoverride
- ethicsPolicy ↔ dynamic
-
Statement about ethics policy, e.g. of a SchemaNewsMediaOrganization
regarding journalistic and publishing practices, or of a
SchemaRestaurant, a page describing food source policies. In the case
of a SchemaNewsMediaOrganization, an ethicsPolicy is typically a
statement describing the personal, organizational, and corporate
standards of behavior expected by the organization.
getter/setter pairoverride
- event ↔ SchemaEvent?
-
Upcoming or past event associated with this place, organization, or
action.
getter/setter pairinherited
- events ↔ SchemaEvent?
-
Upcoming or past events associated with this place or organization.
getter/setter pairinherited
- faxNumber ↔ String?
-
The fax number.
getter/setter pairinherited
- floorLevel ↔ String?
-
//en.wikipedia.org/wiki/Storey#Consecutive_number_floor_designations),
the local system should be used where possible.
getter/setter pairoverride
- founder ↔ dynamic
-
A person or organization who founded this organization.
getter/setter pairoverride
- founders ↔ SchemaPerson?
-
A person who founded this organization.
getter/setter pairoverride
- foundingDate ↔ String?
-
The date that this organization was founded.
getter/setter pairoverride
- foundingLocation ↔ SchemaPlace?
-
The place where the Organization was founded.
getter/setter pairoverride
- funder ↔ dynamic
-
A person or organization that supports (sponsors) something through some
kind of financial contribution.
getter/setter pairoverride
- funding ↔ SchemaGrant?
-
A SchemaGrant that directly or indirectly provide funding or
sponsorship for this item. See also
SchemaownershipFundingInfo.getter/setter pairoverride - geo ↔ dynamic
-
The geo coordinates of the place.
getter/setter pairinherited
- geoContains ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoCoveredBy ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoCovers ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoCrosses ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoDisjoint ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).)
getter/setter pairinherited
- geoEquals ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM). "Two geometries are topologically equal
if their interiors intersect and no part of the interior or boundary of
one geometry intersects the exterior of the other" (a symmetric
relationship).
getter/setter pairinherited
- geoIntersects ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoOverlaps ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoTouches ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).)
getter/setter pairinherited
- geoWithin ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- globalLocationNumber ↔ String?
-
//www.gs1.org/gln) (GLN, sometimes also referred to as International
Location Number or ILN) of the respective organization, person, or place.
The GLN is a 13-digit number used to identify parties and physical
locations.
getter/setter pairinherited
- hasCertification ↔ SchemaCertification?
-
Certification information about a product, organization, service, place,
or person.
getter/setter pairinherited
- hasCredential ↔ SchemaCredential?
-
A credential awarded to the Person or Organization.
getter/setter pairoverride
- hasDriveThroughService ↔ bool?
-
Indicates whether some facility (e.g. SchemaFoodEstablishment,
SchemaCovidTestingFacility) offers a service that can be used by
driving through in a car. In the case of SchemaCovidTestingFacility
such facilities could potentially help with social distancing from other
potentially-infected users.
getter/setter pairinherited
- hasGS1DigitalLink ↔ String?
-
- A Digital Link that contains a serial number (AI
21) should only be present on instances of [SchemaIndividualProduct]- A Digital Link that contains a lot number (AI
10) should be annotated as [SchemaSomeProducts] if only products from that lot are sold, or [SchemaIndividualProduct] if there is only a specific product.- A Digital Link that contains a global model number (AI
8013) should be attached to a [SchemaProduct] or a [SchemaProductModel].getter/setter pairinherited - A Digital Link that contains a serial number (AI
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMap ↔ dynamic
-
A URL to a map of the place.
getter/setter pairinherited
- hasMemberProgram ↔ SchemaMemberProgram?
-
MemberProgram offered by an Organization, for example an eCommerce
merchant or an airline.
getter/setter pairoverride
- hasMerchantReturnPolicy ↔ SchemaMerchantReturnPolicy?
-
Specifies a MerchantReturnPolicy that may be applicable.
getter/setter pairoverride
- hasOfferCatalog ↔ SchemaOfferCatalog?
-
Indicates an OfferCatalog listing for this Organization, Person, or
Service.
getter/setter pairoverride
- hasPOS ↔ SchemaPlace?
-
Points-of-Sales operated by the organization or person.
getter/setter pairoverride
- hasShippingService ↔ SchemaShippingService?
-
Specification of a shipping service offered by the organization.
getter/setter pairoverride
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - interactionStatistic ↔ SchemaInteractionCounter?
-
The number of interactions for the CreativeWork using the WebSite or
SoftwareApplication. The most specific child type of InteractionCounter
should be used.
getter/setter pairoverride
- isAccessibleForFree ↔ bool?
-
A flag to signal that the item, event, or place is accessible for free.
getter/setter pairinherited
- isicV4 ↔ String?
-
The International Standard of Industrial Classification of All Economic
Activities (ISIC), Revision 4 code for a particular organization,
business person, or place.
getter/setter pairinherited
- iso6523Code ↔ String?
-
//schema.org/taxID), as ISO identifiers are less ambiguous.
getter/setter pairoverride
- keywords ↔ dynamic
-
Keywords or tags used to describe some item. Multiple textual entries in
a keywords list are typically delimited by commas, or by repeating the
property.
getter/setter pairinherited
- knowsAbout ↔ dynamic
-
Of a SchemaPerson, and less typically of an SchemaOrganization, to
indicate a topic that is known about - suggesting possible expertise but
not implying it. We do not distinguish skill levels here, or relate this
to educational content, events, objectives or SchemaJobPosting
descriptions.
getter/setter pairoverride
- knowsLanguage ↔ dynamic
-
//tools.ietf.org/html/bcp47).
getter/setter pairoverride
- latitude ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)).
getter/setter pairinherited
- legalAddress ↔ SchemaPostalAddress?
-
The legal address of an organization which acts as the officially
registered address used for legal and tax purposes. The legal address can
be different from the place of operations of a business and other
addresses can be part of an organization.
getter/setter pairoverride
- legalName ↔ String?
-
The official name of the organization, e.g. the registered company name.
getter/setter pairoverride
- legalRepresentative ↔ SchemaPerson?
-
One or multiple persons who represent this organization legally such as
CEO or sole administrator.
getter/setter pairoverride
- leiCode ↔ String?
-
An organization identifier that uniquely identifies a legal entity as
defined in ISO 17442.
getter/setter pairoverride
- location ↔ dynamic
-
The location of, for example, where an event is happening, where an
organization is located, or where an action takes place.
getter/setter pairoverride
- logo ↔ dynamic
-
An associated logo.
getter/setter pairinherited
- longitude ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)).
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- makesOffer ↔ SchemaOffer?
-
A pointer to products or services offered by the organization or person.
getter/setter pairoverride
- map ↔ String?
-
A URL to a map of the place.
getter/setter pairinherited
- maps ↔ String?
-
A URL to a map of the place.
getter/setter pairinherited
- maximumAttendeeCapacity ↔ int?
-
The total number of individuals that may attend an event or venue.
getter/setter pairinherited
- member ↔ dynamic
-
A member of an Organization or a ProgramMembership. Organizations can be
members of organizations; ProgramMembership is typically for individuals.
getter/setter pairoverride
- memberOf ↔ dynamic
-
An Organization (or ProgramMembership) to which this Person or
Organization belongs.
getter/setter pairoverride
- members ↔ dynamic
-
A member of this organization.
getter/setter pairoverride
- naics ↔ String?
-
The North American Industry Classification System (NAICS) code for a
particular organization or business person.
getter/setter pairoverride
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- nonprofitStatus ↔ SchemaNonprofitType?
-
nonprofitStatus indicates the legal status of a non-profit organization
in its primary place of business.
getter/setter pairoverride
- numberOfEmployees ↔ SchemaQuantitativeValue?
-
The number of employees in an organization, e.g. business.
getter/setter pairoverride
- numberOfRooms ↔ dynamic
-
ROM for room or C62 for no unit. The type of room can be put in the
unitText property of the QuantitativeValue.
getter/setter pairoverride
- openingHours ↔ String?
-
00">Tuesdays and Thursdays 4-8pm</time>.\n* If a
business is open 7 days a week, then it can be specified as
<time itemprop="openingHours" datetime="Mo-Su">Monday through Sunday, all day</time>.getter/setter pairinherited - openingHoursSpecification ↔ SchemaOpeningHoursSpecification?
-
The opening hours of a certain place.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- ownershipFundingInfo ↔ dynamic
-
For an SchemaOrganization (often but not necessarily a
SchemaNewsMediaOrganization), a description of organizational ownership
structure; funding and grants. In a news/media setting, this is with
particular reference to editorial independence. Note that the
Schemafunderis also available and can be used to make basic funder information machine-readable.getter/setter pairoverride - owns ↔ SchemaThing?
-
Things owned by the organization or person.
getter/setter pairoverride
- parentOrganization ↔ SchemaOrganization?
-
The larger organization that this organization is a
SchemasubOrganizationof, if any.getter/setter pairoverride - paymentAccepted ↔ String?
-
Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.
getter/setter pairoverride
- petsAllowed ↔ dynamic
-
Indicates whether pets are allowed to enter the accommodation or lodging
business. More detailed information can be put in a text value.
getter/setter pairoverride
- photo ↔ dynamic
-
A photograph of this place.
getter/setter pairinherited
- photos ↔ dynamic
-
Photographs of this place.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- priceRange ↔ String?
-
The price range of the business, for example
$$$.getter/setter pairoverride - publicAccess ↔ bool?
-
A flag to signal that the SchemaPlace is open to public visitors. If
this property is omitted there is no assumed default boolean value.
getter/setter pairinherited
- publishingPrinciples ↔ dynamic
-
The publishingPrinciples property indicates (typically via
SchemaURL) a document describing the editorial principles of an SchemaOrganization (or individual, e.g. a SchemaPerson writing a blog) that relate to their activities as a publisher, e.g. ethics or diversity policies. When applied to a SchemaCreativeWork (e.g. SchemaNewsArticle) the principles are those of the party primarily responsible for the creation of the SchemaCreativeWork.getter/setter pairoverride - review ↔ SchemaReview?
-
A review of the item.
getter/setter pairinherited
- reviews ↔ SchemaReview?
-
Review of the item.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- seeks ↔ SchemaDemand?
-
A pointer to products or services sought by the organization or person
(demand).
getter/setter pairoverride
- serviceArea ↔ dynamic
-
The geographic area where the service is provided.
getter/setter pairoverride
- skills ↔ dynamic
-
A statement of knowledge, skill, ability, task or any other assertion
expressing a competency that is either claimed by a person, an
organization or desired or required to fulfill a role or to work in an
occupation.
getter/setter pairoverride
- slogan ↔ String?
-
A slogan or motto associated with the item.
getter/setter pairinherited
- smokingAllowed ↔ bool?
-
Indicates whether it is allowed to smoke in the place, e.g. in the
restaurant, hotel or hotel room.
getter/setter pairinherited
- specialOpeningHoursSpecification ↔ SchemaOpeningHoursSpecification?
-
The special opening hours of a certain place.\n\nUse this to explicitly
override general opening hours brought in scope by
SchemaopeningHoursSpecificationorSchemaopeningHours.getter/setter pairinherited - sponsor ↔ dynamic
-
A person or organization that supports a thing through a pledge, promise,
or financial contribution. E.g. a sponsor of a Medical Study or a
corporate sponsor of an event.
getter/setter pairoverride
- starRating ↔ SchemaRating?
-
An official rating for a lodging business or food establishment, e.g.
from national associations or standards bodies. Use the author property
to indicate the rating organization, e.g. as an Organization with name
such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).
getter/setter pairoverride
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- subOrganization ↔ SchemaOrganization?
-
the more specific 'department' property.
getter/setter pairoverride
- taxID ↔ String?
-
The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US
or the CIF/NIF in Spain.
getter/setter pairoverride
- telephone ↔ String?
-
The telephone number.
getter/setter pairinherited
- tourBookingPage ↔ String?
-
A page providing information on how to book a tour of some SchemaPlace,
such as an SchemaAccommodation or SchemaApartmentComplex in a real
estate setting, as well as other kinds of tours as appropriate.
getter/setter pairinherited
- unnamedSourcesPolicy ↔ dynamic
-
For an SchemaOrganization (typically a SchemaNewsMediaOrganization),
a statement about policy on use of unnamed sources and the decision
process required.
getter/setter pairoverride
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
- vatID ↔ String?
-
The value-added Tax ID of the organization or person with national prefix
(for example IT123456789). Can also be described as
Schemaiso6523Codewith proper prefix.getter/setter pairoverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaCampground to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited