cvdNumBeds property
Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.
Implementation
num? cvdNumBeds;
Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.
num? cvdNumBeds;