SchemaConstraintNode class
The ConstraintNode type is provided to support usecases in which a node
in a structured data graph is described with properties which appear to
describe a single entity, but are being used in a situation where they
serve a more abstract purpose. A SchemaConstraintNode can be described
using SchemaconstraintProperty and SchemanumConstraints. These
constraint properties can serve a variety of purposes, and their values
may sometimes be understood to indicate sets of possible values rather
than single, exact and specific values.
See https://schema.org/ConstraintNode
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaConstraintNode
- Implementers
Constructors
- SchemaConstraintNode({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic constraintProperty, int? numConstraints})
- Create a new instance of SchemaConstraintNode
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- constraintProperty ↔ dynamic
-
Indicates a property used as a constraint. For example, in the definition
of a SchemaStatisticalVariable. The value is a property, either from
within Schema.org or from other compatible (e.g. RDF) systems such as
DataCommons.org or Wikidata.org.
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- numConstraints ↔ int?
-
Indicates the number of constraints property values defined for a
particular SchemaConstraintNode such as SchemaStatisticalVariable.
This helps applications understand if they have access to a sufficiently
complete description of a SchemaStatisticalVariable or other construct
that is defined using properties on template-style nodes.
getter/setter pair
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaConstraintNode to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited