schemaVersion property
//dublincore.org/specifications/dublin-core/dces/1999-07-02/``` but this has not been carefully explored in the community.
Implementation
String? schemaVersion;
//dublincore.org/specifications/dublin-core/dces/1999-07-02/``` but this has not been carefully explored in the community.
String? schemaVersion;