monthlyMinimumRepaymentAmount property

  1. @override
dynamic monthlyMinimumRepaymentAmount
getter/setter pairoverride

The minimum payment is the lowest amount of money that one is required to pay on a credit card statement each month.

Supported types: SchemaMonetaryAmount, num

Implementation

@override
dynamic monthlyMinimumRepaymentAmount;