SchemaDatedMoneySpecification class

__ This type has been superseded by SchemaMonetaryAmount, use of that type is recommended. See https://schema.org/DatedMoneySpecification

Inheritance
Annotations
  • @Deprecated('Use [SchemaMonetaryAmount]. See https://schema.org/DatedMoneySpecification')

Constructors

SchemaDatedMoneySpecification({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic amount, String? currency, String? endDate, String? startDate})
Create a new instance of SchemaDatedMoneySpecification

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
amount ↔ dynamic
The amount of money.
getter/setter pair
currency String?
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
endDate String?
//en.wikipedia.org/wiki/ISO_8601)).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
startDate String?
//en.wikipedia.org/wiki/ISO_8601)).
getter/setter pair
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaDatedMoneySpecification to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited