schemas/defined_term_set library
Classes
- SchemaDefinedTermSet
- A set of defined terms, for example a set of categories or a classification scheme, a glossary, dictionary or enumeration. Use the about property to specify what the term set is about. See https://schema.org/DefinedTermSet