SchemaDemand class

A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply. See https://schema.org/Demand

Inheritance

Constructors

SchemaDemand({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic acceptedPaymentMethod, SchemaQuantitativeValue? advanceBookingRequirement, dynamic areaServed, String? asin, SchemaItemAvailability? availability, String? availabilityEnds, String? availabilityStarts, SchemaPlace? availableAtOrFrom, SchemaDeliveryMethod? availableDeliveryMethod, SchemaBusinessFunction? businessFunction, SchemaQuantitativeValue? deliveryLeadTime, SchemaBusinessEntityType? eligibleCustomerType, SchemaQuantitativeValue? eligibleDuration, SchemaQuantitativeValue? eligibleQuantity, dynamic eligibleRegion, SchemaPriceSpecification? eligibleTransactionVolume, String? gtin, String? gtin12, String? gtin13, String? gtin14, String? gtin8, SchemaTypeAndQuantityNode? includesObject, dynamic ineligibleRegion, SchemaQuantitativeValue? inventoryLevel, SchemaOfferItemCondition? itemCondition, dynamic itemOffered, String? mpn, SchemaPriceSpecification? priceSpecification, dynamic seller, String? serialNumber, String? sku, String? validFrom, String? validThrough, SchemaWarrantyPromise? warranty})
Create a new instance of SchemaDemand

Properties

acceptedPaymentMethod ↔ dynamic
The payment method(s) that are accepted in general by an organization, or for some specific demand or offer.
getter/setter pair
additionalType ↔ String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
advanceBookingRequirement ↔ SchemaQuantitativeValue?
The amount of time that is required between accepting the offer and the actual usage of the resource or service.
getter/setter pair
alternateName ↔ String?
An alias for the item.
getter/setter pairinherited
areaServed ↔ dynamic
The geographic area where a service or offered item is provided.
getter/setter pair
asin ↔ String?
//en.wikipedia.org/wiki/Amazon_Standard_Identification_Number)'s article).
getter/setter pair
availability ↔ SchemaItemAvailability?
The availability of this item—for example In stock, Out of stock, Pre-order, etc.
getter/setter pair
availabilityEnds ↔ String?
The end of the availability of the product or service included in the offer.
getter/setter pair
availabilityStarts ↔ String?
The beginning of the availability of the product or service included in the offer.
getter/setter pair
availableAtOrFrom ↔ SchemaPlace?
The place(s) from which the offer can be obtained (e.g. store locations).
getter/setter pair
availableDeliveryMethod ↔ SchemaDeliveryMethod?
The delivery method(s) available for this offer.
getter/setter pair
businessFunction ↔ SchemaBusinessFunction?
//purl.org/goodrelations/v1#Sell.
getter/setter pair
deliveryLeadTime ↔ SchemaQuantitativeValue?
The typical delay between the receipt of the order and the goods either leaving the warehouse or being prepared for pickup, in case the delivery method is on site pickup.
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription ↔ String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
eligibleCustomerType ↔ SchemaBusinessEntityType?
The type(s) of customers for which the given offer is valid.
getter/setter pair
eligibleDuration ↔ SchemaQuantitativeValue?
The duration for which the given offer is valid.
getter/setter pair
eligibleQuantity ↔ SchemaQuantitativeValue?
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
getter/setter pair
eligibleRegion ↔ dynamic
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.\n\nSee also SchemaineligibleRegion.
getter/setter pair
eligibleTransactionVolume ↔ SchemaPriceSpecification?
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
getter/setter pair
gtin ↔ String?
//www.gs1.org/standards/Digital-Link/) expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the SchemahasGS1DigitalLink attribute.
getter/setter pair
gtin12 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pair
gtin13 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pair
gtin14 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pair
gtin8 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
includesObject ↔ SchemaTypeAndQuantityNode?
This links to a node or nodes indicating the exact quantity of the products included in an SchemaOffer or SchemaProductCollection.
getter/setter pair
ineligibleRegion ↔ dynamic
The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, the place, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is not valid, e.g. a region where the transaction is not allowed.\n\nSee also SchemaeligibleRegion.
getter/setter pair
inventoryLevel ↔ SchemaQuantitativeValue?
The current approximate inventory level for the item or items.
getter/setter pair
itemCondition ↔ SchemaOfferItemCondition?
A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.
getter/setter pair
itemOffered ↔ dynamic
An item being offered (or demanded). The transactional nature of the offer or demand is documented using SchemabusinessFunction, e.g. sell, lease etc. While several common expected types are listed explicitly in this definition, others can be used. Using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
getter/setter pair
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
mpn ↔ String?
The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
getter/setter pair
name ↔ String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction ↔ SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
priceSpecification ↔ SchemaPriceSpecification?
One or more detailed price specifications, indicating the unit price and delivery or payment charges.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameAs ↔ String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
seller ↔ dynamic
An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
getter/setter pair
serialNumber ↔ String?
The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.
getter/setter pair
sku ↔ String?
The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
getter/setter pair
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url ↔ String?
URL of the item.
getter/setter pairinherited
validFrom ↔ String?
The date when the item becomes valid.
getter/setter pair
validThrough ↔ String?
The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.
getter/setter pair
warranty ↔ SchemaWarrantyPromise?
The warranty promise(s) included in the offer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → Map<String, dynamic>
Serialize SchemaDemand to JSON-LD
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited