SchemaDrawing class

A picture or diagram made with a pencil, pen, or crayon rather than paint. See https://schema.org/Drawing

Inheritance

Constructors

SchemaDrawing({SchemaThing? about, String? abstract, String? accessMode, SchemaItemList? accessModeSufficient, String? accessibilityAPI, String? accessibilityControl, String? accessibilityFeature, String? accessibilityHazard, String? accessibilitySummary, SchemaPerson? accountablePerson, dynamic acquireLicensePage, String? additionalType, SchemaAggregateRating? aggregateRating, String? alternateName, String? alternativeHeadline, dynamic archivedAt, dynamic assesses, SchemaMediaObject? associatedMedia, SchemaAudience? audience, dynamic audio, dynamic author, String? award, String? awards, SchemaPerson? character, dynamic citation, SchemaComment? comment, int? commentCount, String? conditionsOfAccess, SchemaPlace? contentLocation, dynamic contentRating, String? contentReferenceTime, dynamic contributor, dynamic copyrightHolder, String? copyrightNotice, num? copyrightYear, dynamic correction, SchemaCountry? countryOfOrigin, dynamic creativeWorkStatus, dynamic creator, String? creditText, String? dateCreated, String? dateModified, String? datePublished, dynamic description, SchemaIPTCDigitalSourceEnumeration? digitalSourceType, String? disambiguatingDescription, String? discussionUrl, SchemaPlace? displayLocation, String? editEIDR, SchemaPerson? editor, SchemaAlignmentObject? educationalAlignment, dynamic educationalLevel, dynamic educationalUse, SchemaMediaObject? encoding, String? encodingFormat, SchemaMediaObject? encodings, SchemaCreativeWork? exampleOfWork, String? expires, String? fileFormat, dynamic funder, SchemaGrant? funding, dynamic genre, SchemaCreativeWork? hasPart, String? headline, dynamic identifier, dynamic image, dynamic inLanguage, SchemaInteractionCounter? interactionStatistic, String? interactivityType, SchemaClaim? interpretedAsClaim, bool? isAccessibleForFree, dynamic isBasedOn, dynamic isBasedOnUrl, bool? isFamilyFriendly, dynamic isPartOf, dynamic keywords, dynamic learningResourceType, dynamic license, SchemaPlace? locationCreated, SchemaThing? mainEntity, dynamic mainEntityOfPage, dynamic maintainer, dynamic material, dynamic materialExtent, SchemaThing? mentions, String? name, dynamic offers, dynamic owner, dynamic pattern, dynamic position, SchemaAction? potentialAction, dynamic producer, dynamic provider, SchemaPublicationEvent? publication, dynamic publisher, SchemaOrganization? publisherImprint, dynamic publishingPrinciples, SchemaEvent? recordedAt, SchemaPublicationEvent? releasedEvent, SchemaReview? review, SchemaReview? reviews, String? sameAs, String? schemaVersion, String? sdDatePublished, dynamic sdLicense, dynamic sdPublisher, dynamic size, SchemaOrganization? sourceOrganization, SchemaPlace? spatial, SchemaPlace? spatialCoverage, dynamic sponsor, dynamic subjectOf, dynamic teaches, String? temporal, String? temporalCoverage, String? text, SchemaImageObject? thumbnail, String? thumbnailUrl, SchemaDuration? timeRequired, SchemaCreativeWork? translationOfWork, dynamic translator, String? typicalAgeRange, String? url, dynamic usageInfo, dynamic version, dynamic video, int? wordCount, SchemaCreativeWork? workExample, SchemaCreativeWork? workTranslation})
Create a new instance of SchemaDrawing

Properties

about SchemaThing?
The subject matter of an object.
getter/setter pairinherited
abstract String?
An abstract is a short description that summarizes a SchemaCreativeWork.
getter/setter pairinherited
accessibilityAPI String?
//www.w3.org/2021/a11y-discov-vocab/latest/#accessibilityAPI-vocabulary).
getter/setter pairinherited
accessibilityControl String?
//www.w3.org/2021/a11y-discov-vocab/latest/#accessibilityControl-vocabulary).
getter/setter pairinherited
accessibilityFeature String?
//www.w3.org/2021/a11y-discov-vocab/latest/#accessibilityFeature-vocabulary).
getter/setter pairinherited
accessibilityHazard String?
//www.w3.org/2021/a11y-discov-vocab/latest/#accessibilityHazard-vocabulary).
getter/setter pairinherited
accessibilitySummary String?
A human-readable summary of specific accessibility features or deficiencies, consistent with the other accessibility metadata but expressing subtleties such as "short descriptions are present but long descriptions will be needed for non-visual users" or "short descriptions are present and no long descriptions are needed".
getter/setter pairinherited
accessMode String?
//www.w3.org/2021/a11y-discov-vocab/latest/#accessMode-vocabulary).
getter/setter pairinherited
accessModeSufficient SchemaItemList?
//www.w3.org/2021/a11y-discov-vocab/latest/#accessModeSufficient-vocabulary).
getter/setter pairinherited
accountablePerson SchemaPerson?
Specifies the Person that is legally accountable for the CreativeWork.
getter/setter pairinherited
acquireLicensePage ↔ dynamic
Indicates a page documenting how licenses can be purchased or otherwise acquired, for the current item.
getter/setter pairinherited
additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
aggregateRating SchemaAggregateRating?
The overall rating, based on a collection of reviews or ratings, of the item.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
alternativeHeadline String?
A secondary title of the CreativeWork.
getter/setter pairinherited
archivedAt ↔ dynamic
Indicates a page or other link involved in archival of a SchemaCreativeWork. In the case of SchemaMediaReview, the items in a SchemaMediaReviewItem may often become inaccessible, but be archived by archival, journalistic, activist, or law enforcement organizations. In such cases, the referenced page may not directly publish the content.
getter/setter pairinherited
assesses ↔ dynamic
The item being described is intended to assess the competency or learning outcome defined by the referenced term.
getter/setter pairinherited
associatedMedia SchemaMediaObject?
A media object that encodes this CreativeWork. This property is a synonym for encoding.
getter/setter pairinherited
audience SchemaAudience?
An intended audience, i.e. a group for whom something was created.
getter/setter pairinherited
audio ↔ dynamic
An embedded audio object.
getter/setter pairinherited
author ↔ dynamic
The author of this content or rating. Please note that author is special in that HTML 5 provides a special mechanism for indicating authorship via the rel tag. That is equivalent to this and may be used interchangeably.
getter/setter pairinherited
award String?
An award won by or for this item.
getter/setter pairinherited
awards String?
Awards won by or for this item.
getter/setter pairinherited
character SchemaPerson?
Fictional person connected with a creative work.
getter/setter pairinherited
citation ↔ dynamic
A citation or reference to another creative work, such as another publication, web page, scholarly article, etc.
getter/setter pairinherited
comment SchemaComment?
Comments, typically from users.
getter/setter pairinherited
commentCount int?
The number of comments this CreativeWork (e.g. Article, Question or Answer) has received. This is most applicable to works published in Web sites with commenting system; additional comments may exist elsewhere.
getter/setter pairinherited
conditionsOfAccess String?
Conditions that affect the availability of, or method(s) of access to, an item. Typically used for real world items such as an SchemaArchiveComponent held by an SchemaArchiveOrganization. This property is not suitable for use as a general Web access control mechanism. It is expressed only in natural language.\n\nFor example "Available by appointment from the Reading Room" or "Accessible only from logged-in accounts ".
getter/setter pairinherited
contentLocation SchemaPlace?
The location depicted or described in the content. For example, the location in a photograph or painting.
getter/setter pairinherited
contentRating ↔ dynamic
Official rating of a piece of content—for example, 'MPAA PG-13'.
getter/setter pairinherited
contentReferenceTime String?
The specific time described by a creative work, for works (e.g. articles, video objects etc.) that emphasise a particular moment within an Event.
getter/setter pairinherited
contributor ↔ dynamic
A secondary contributor to the CreativeWork or Event.
getter/setter pairinherited
copyrightHolder ↔ dynamic
The party holding the legal copyright to the CreativeWork.
getter/setter pairinherited
copyrightNotice String?
Text of a notice appropriate for describing the copyright aspects of this Creative Work, ideally indicating the owner of the copyright for the Work.
getter/setter pairinherited
copyrightYear num?
The year during which the claimed copyright for the CreativeWork was first asserted.
getter/setter pairinherited
correction ↔ dynamic
Indicates a correction to a SchemaCreativeWork, either via a SchemaCorrectionComment, textually or in another document.
getter/setter pairinherited
countryOfOrigin SchemaCountry?
The country of origin of something, including products as well as creative works such as movie and TV content.
getter/setter pairinherited
creativeWorkStatus ↔ dynamic
The status of a creative work in terms of its stage in a lifecycle. Example terms include Incomplete, Draft, Published, Obsolete. Some organizations define a set of terms for the stages of their publication lifecycle.
getter/setter pairinherited
creator ↔ dynamic
The creator/author of this CreativeWork. This is the same as the Author property for CreativeWork.
getter/setter pairinherited
creditText String?
Text that can be used to credit person(s) and/or organization(s) associated with a published Creative Work.
getter/setter pairinherited
dateCreated String?
The date on which the CreativeWork was created or the item was added to a DataFeed.
getter/setter pairinherited
dateModified String?
The date on which the CreativeWork was most recently modified or when the item's entry was modified within a DataFeed.
getter/setter pairinherited
datePublished String?
Date of first publication or broadcast. For example the date a SchemaCreativeWork was broadcast or a SchemaCertification was issued.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
digitalSourceType SchemaIPTCDigitalSourceEnumeration?
Indicates an IPTCDigitalSourceEnumeration code indicating the nature of the digital source(s) for some SchemaCreativeWork.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
discussionUrl String?
A link to the page containing the comments of the CreativeWork.
getter/setter pairinherited
displayLocation SchemaPlace?
The location at which an item can be viewed or experienced in-person.
getter/setter pairinherited
editEIDR String?
//eidr.org/) (Entertainment Identifier Registry) Schemaidentifier representing a specific edit / edition for a work of film or television.
getter/setter pairinherited
editor SchemaPerson?
Specifies the Person who edited the CreativeWork.
getter/setter pairinherited
educationalAlignment SchemaAlignmentObject?
An alignment to an established educational framework.
getter/setter pairinherited
educationalLevel ↔ dynamic
The level in terms of progression through an educational or training context. Examples of educational levels include 'beginner', 'intermediate' or 'advanced', and formal sets of level indicators.
getter/setter pairinherited
educationalUse ↔ dynamic
The purpose of a work in the context of education; for example, 'assignment', 'group work'.
getter/setter pairinherited
encoding SchemaMediaObject?
A media object that encodes this CreativeWork. This property is a synonym for associatedMedia.
getter/setter pairinherited
encodingFormat String?
//developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types)), e.g. application/zip for a SoftwareApplication binary, audio/mpeg for .mp3 etc.
getter/setter pairinherited
encodings SchemaMediaObject?
A media object that encodes this CreativeWork.
getter/setter pairinherited
exampleOfWork SchemaCreativeWork?
A creative work that this work is an example/instance/realization/derivation of.
getter/setter pairinherited
expires String?
Date the content expires and is no longer useful or available. For example a SchemaVideoObject or SchemaNewsArticle whose availability or relevance is time-limited, a SchemaClaimReview fact check whose publisher wants to indicate that it may no longer be relevant (or helpful to highlight) after some date, or a SchemaCertification the validity has expired.
getter/setter pairinherited
fileFormat String?
//www.iana.org/assignments/media-types/media-types.xhtml)) of the content, e.g. application/zip of a SoftwareApplication binary. In cases where a CreativeWork has several media type representations, 'encoding' can be used to indicate each MediaObject alongside particular fileFormat information. Unregistered or niche file formats can be indicated instead via the most appropriate URL, e.g. defining Web page or a Wikipedia entry.
getter/setter pairinherited
funder ↔ dynamic
A person or organization that supports (sponsors) something through some kind of financial contribution.
getter/setter pairinherited
funding SchemaGrant?
A SchemaGrant that directly or indirectly provide funding or sponsorship for this item. See also SchemaownershipFundingInfo.
getter/setter pairinherited
genre ↔ dynamic
Genre of the creative work, broadcast channel or group.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hasPart SchemaCreativeWork?
Indicates an item or CreativeWork that is part of this item, or CreativeWork (in some sense).
getter/setter pairinherited
headline String?
Headline of the article.
getter/setter pairinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
inLanguage ↔ dynamic
//tools.ietf.org/html/bcp47). See also SchemaavailableLanguage.
getter/setter pairinherited
interactionStatistic SchemaInteractionCounter?
The number of interactions for the CreativeWork using the WebSite or SoftwareApplication. The most specific child type of InteractionCounter should be used.
getter/setter pairinherited
interactivityType String?
The predominant mode of learning supported by the learning resource. Acceptable values are 'active', 'expositive', or 'mixed'.
getter/setter pairinherited
interpretedAsClaim SchemaClaim?
Used to indicate a specific claim contained, implied, translated or refined from the content of a SchemaMediaObject or other SchemaCreativeWork. The interpreting party can be indicated using SchemaclaimInterpreter.
getter/setter pairinherited
isAccessibleForFree bool?
A flag to signal that the item, event, or place is accessible for free.
getter/setter pairinherited
isBasedOn ↔ dynamic
A resource from which this work is derived or from which it is a modification or adaptation.
getter/setter pairinherited
isBasedOnUrl ↔ dynamic
//example.com/great-multiplication-intro.html.
getter/setter pairinherited
isFamilyFriendly bool?
Indicates whether this content is family friendly.
getter/setter pairinherited
isPartOf ↔ dynamic
Indicates an item or CreativeWork that this item, or CreativeWork (in some sense), is part of.
getter/setter pairinherited
keywords ↔ dynamic
Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.
getter/setter pairinherited
learningResourceType ↔ dynamic
The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'.
getter/setter pairinherited
license ↔ dynamic
A license document that applies to this content, typically indicated by URL.
getter/setter pairinherited
locationCreated SchemaPlace?
The location where the CreativeWork was created, which may not be the same as the location depicted in the CreativeWork.
getter/setter pairinherited
mainEntity SchemaThing?
Indicates the primary entity described in some page or other CreativeWork.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
maintainer ↔ dynamic
A maintainer of a SchemaDataset, software package (SchemaSoftwareApplication), or other SchemaProject. A maintainer is a SchemaPerson or SchemaOrganization that manages contributions to, and/or publication of, some (typically complex) artifact. It is common for distributions of software and data to be based on "upstream" sources. When Schemamaintainer is applied to a specific version of something e.g. a particular version or packaging of a SchemaDataset, it is always possible that the upstream source has a different maintainer. The SchemaisBasedOn property can be used to indicate such relationships between datasets to make the different maintenance roles clear. Similarly in the case of software, a package may have dedicated maintainers working on integration into software distributions such as Ubuntu, as well as upstream maintainers of the underlying work.
getter/setter pairinherited
material ↔ dynamic
A material that something is made from, e.g. leather, wool, cotton, paper.
getter/setter pairinherited
materialExtent ↔ dynamic
The quantity of the materials being described or an expression of the physical space they occupy.
getter/setter pairinherited
mentions SchemaThing?
Indicates that the CreativeWork contains a reference to, but is not necessarily about a concept.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
offers ↔ dynamic
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use SchemabusinessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
pattern ↔ dynamic
A pattern that something has, for example 'polka dot', 'striped', 'Canadian flag'. Values are typically expressed as text, although links to controlled value schemes are also supported.
getter/setter pairinherited
position ↔ dynamic
The position of an item in a series or sequence of items.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
producer ↔ dynamic
The person or organization who produced the work (e.g. music album, movie, TV/radio series etc.).
getter/setter pairinherited
provider ↔ dynamic
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
getter/setter pairinherited
publication SchemaPublicationEvent?
A publication event associated with the item.
getter/setter pairinherited
publisher ↔ dynamic
The publisher of the article in question.
getter/setter pairinherited
publisherImprint SchemaOrganization?
The publishing division which published the comic.
getter/setter pairinherited
publishingPrinciples ↔ dynamic
The publishingPrinciples property indicates (typically via SchemaURL) a document describing the editorial principles of an SchemaOrganization (or individual, e.g. a SchemaPerson writing a blog) that relate to their activities as a publisher, e.g. ethics or diversity policies. When applied to a SchemaCreativeWork (e.g. SchemaNewsArticle) the principles are those of the party primarily responsible for the creation of the SchemaCreativeWork.
getter/setter pairinherited
recordedAt SchemaEvent?
The Event where the CreativeWork was recorded. The CreativeWork may capture all or part of the event.
getter/setter pairinherited
releasedEvent SchemaPublicationEvent?
The place and time the release was issued, expressed as a PublicationEvent.
getter/setter pairinherited
review SchemaReview?
A review of the item.
getter/setter pairinherited
reviews SchemaReview?
Review of the item.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
schemaVersion String?
//dublincore.org/specifications/dublin-core/dces/1999-07-02/``` but this has not been carefully explored in the community.
getter/setter pairinherited
sdDatePublished String?
Indicates the date on which the current structured data was generated / published. Typically used alongside SchemasdPublisher.
getter/setter pairinherited
sdLicense ↔ dynamic
A license document that applies to this structured data, typically indicated by URL.
getter/setter pairinherited
sdPublisher ↔ dynamic
Indicates the party responsible for generating and publishing the current structured data markup, typically in cases where the structured data is derived automatically from existing published content but published on a different site. For example, student projects and open data initiatives often re-publish existing content with more explicitly structured metadata. The SchemasdPublisher property helps make such practices more explicit.
getter/setter pairinherited
size ↔ dynamic
A standardized size of a product or creative work, specified either through a simple textual string (for example 'XL', '32Wx34L'), a QuantitativeValue with a unitCode, or a comprehensive and structured SchemaSizeSpecification; in other cases, the Schemawidth, Schemaheight, Schemadepth and Schemaweight properties may be more applicable.
getter/setter pairinherited
sourceOrganization SchemaOrganization?
The Organization on whose behalf the creator was working.
getter/setter pairinherited
spatial SchemaPlace?
The "spatial" property can be used in cases when more specific properties (e.g. SchemalocationCreated, SchemaspatialCoverage, SchemacontentLocation) are not known to be appropriate.
getter/setter pairinherited
spatialCoverage SchemaPlace?
the state of New York.
getter/setter pairinherited
A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
teaches ↔ dynamic
The item being described is intended to help a person learn the competency or learning outcome defined by the referenced term.
getter/setter pairinherited
temporal String?
The "temporal" property can be used in cases where more specific properties (e.g. SchematemporalCoverage, SchemadateCreated, SchemadateModified, SchemadatePublished) are not known to be appropriate.
getter/setter pairinherited
temporalCoverage String?
//en.wikipedia.org/wiki/ISO_8601#Time_intervals). In the case of a Dataset it will typically indicate the relevant time period in a precise notation (e.g. for a 2011 census dataset, the year 2011 would be written "2011/2012"). Other forms of content, e.g. ScholarlyArticle, Book, TVSeries or TVEpisode, may indicate their temporalCoverage in broader terms - textually or via well-known URL. Written works such as books may sometimes have precise temporal coverage too, e.g. a work set in 1939 - 1945 can be indicated in ISO 8601 interval format format via "1939/1945".
getter/setter pairinherited
text String?
The textual content of this CreativeWork.
getter/setter pairinherited
thumbnail SchemaImageObject?
Thumbnail image for an image or video.
getter/setter pairinherited
thumbnailUrl String?
A thumbnail image relevant to the Thing.
getter/setter pairinherited
timeRequired SchemaDuration?
Approximate or typical time it usually takes to work with or through the content of this work for the typical or target audience.
getter/setter pairinherited
translationOfWork SchemaCreativeWork?
The work that this work has been translated from. E.g. 物种起源 is a translationOf “On the Origin of Species”.
getter/setter pairinherited
translator ↔ dynamic
Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event.
getter/setter pairinherited
typicalAgeRange String?
The typical expected age range, e.g. '7-9', '11-'.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited
usageInfo ↔ dynamic
The schema.org SchemausageInfo property indicates further information about a SchemaCreativeWork. This property is applicable both to works that are freely available and to those that require payment or other transactions. It can reference additional information, e.g. community expectations on preferred linking and citation conventions, as well as purchasing details. For something that can be commercially licensed, usageInfo can provide detailed, resource-specific information about licensing options.
getter/setter pairinherited
version ↔ dynamic
The version of the CreativeWork embodied by a specified resource.
getter/setter pairinherited
video ↔ dynamic
An embedded video object.
getter/setter pairinherited
wordCount int?
The number of words in the text of the CreativeWork such as an Article, Book, etc.
getter/setter pairinherited
workExample SchemaCreativeWork?
Example/instance/realization/derivation of the concept of this creative work. E.g. the paperback edition, first edition, or e-book.
getter/setter pairinherited
workTranslation SchemaCreativeWork?
A work that is a translation of the content of this work. E.g. 西遊記 has an English workTranslation “Journey to the West”, a German workTranslation “Monkeys Pilgerfahrt” and a Vietnamese translation Tây du ký bình khảo.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaDrawing to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited