SchemaDuration class

//en.wikipedia.org/wiki/ISO_8601)). See https://schema.org/Duration

Inheritance

Constructors

SchemaDuration()
Create a new instance of SchemaDuration

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaDuration to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited