applicationDeadline property

String? applicationDeadline
getter/setter pair

The date on which the program stops collecting applications for the next enrollment cycle. Flexible application deadlines (for example, a program with rolling admissions) can be described in a textual string, rather than as a DateTime.

Implementation

String? applicationDeadline;