pathophysiology property

  1. @override
String? pathophysiology
getter/setter pairoverride

Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.

Implementation

@override
String? pathophysiology;