SchemaGameServerStatus enum

Status of a game server. See https://schema.org/GameServerStatus

Inheritance
Implemented types
Available extensions

Values

offlinePermanently → const SchemaGameServerStatus

OfflinePermanently. Server is offline and not available.

const SchemaGameServerStatus('https://schema.org/GameServerStatus')
offlineTemporarily → const SchemaGameServerStatus

OfflineTemporarily. Server is offline now but it can be online soon.

const SchemaGameServerStatus('https://schema.org/GameServerStatus')
online → const SchemaGameServerStatus

Online. Server is available.

const SchemaGameServerStatus('https://schema.org/GameServerStatus')
onlineFull → const SchemaGameServerStatus

OnlineFull. Server is online but unavailable. The maximum number of players has reached.

const SchemaGameServerStatus('https://schema.org/GameServerStatus')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Enum value as a string
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → String
Serialize SchemaGameServerStatus to JSON-LD
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SchemaGameServerStatus>
A constant List of the values in this enum, in order of their declaration.