SchemaGene class
//en.wikipedia.org/wiki/Gene)). Examples include FOXP2 (Forkhead box protein P2), SCARNA21 (small Cajal body-specific RNA 21), A- (agouti genotype). See https://schema.org/Gene
- Inheritance
-
- Object
- SchemaThing
- SchemaBioChemEntity
- SchemaGene
Constructors
- SchemaGene({String? additionalType, String? alternateName, dynamic associatedDisease, SchemaBioChemEntity? bioChemInteraction, SchemaBioChemEntity? bioChemSimilarity, SchemaDefinedTerm? biologicalRole, dynamic description, String? disambiguatingDescription, SchemaGrant? funding, SchemaBioChemEntity? hasBioChemEntityPart, dynamic hasMolecularFunction, dynamic hasRepresentation, dynamic identifier, dynamic image, SchemaGene? isEncodedByBioChemEntity, dynamic isInvolvedInBiologicalProcess, dynamic isLocatedInSubcellularLocation, SchemaBioChemEntity? isPartOfBioChemEntity, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, dynamic taxonomicRange, String? url, SchemaGene? alternativeOf, SchemaBioChemEntity? encodesBioChemEntity, dynamic expressedIn, String? hasBioPolymerSequence})
- Create a new instance of SchemaGene
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- alternativeOf ↔ SchemaGene?
-
Another gene which is a variation of this one.
getter/setter pair
- associatedDisease ↔ dynamic
-
Disease associated to this BioChemEntity. Such disease can be a
MedicalCondition or a URL. If you want to add an evidence supporting the
association, please use PropertyValue.
getter/setter pairinherited
- bioChemInteraction ↔ SchemaBioChemEntity?
-
A BioChemEntity that is known to interact with this item.
getter/setter pairinherited
- bioChemSimilarity ↔ SchemaBioChemEntity?
-
A similar BioChemEntity, e.g., obtained by fingerprint similarity
algorithms.
getter/setter pairinherited
- biologicalRole ↔ SchemaDefinedTerm?
-
A role played by the BioChemEntity within a biological context.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- encodesBioChemEntity ↔ SchemaBioChemEntity?
-
Another BioChemEntity encoded by this one.
getter/setter pair
- expressedIn ↔ dynamic
-
Tissue, organ, biological sample, etc in which activity of this gene has
been observed experimentally. For example brain, digestive system.
getter/setter pair
- funding ↔ SchemaGrant?
-
A SchemaGrant that directly or indirectly provide funding or
sponsorship for this item. See also
SchemaownershipFundingInfo.getter/setter pairinherited - hasBioChemEntityPart ↔ SchemaBioChemEntity?
-
Indicates a BioChemEntity that (in some sense) has this BioChemEntity as
a part.
getter/setter pairinherited
- hasBioPolymerSequence ↔ String?
-
A symbolic representation of a BioChemEntity. For example, a nucleotide
sequence of a Gene or an amino acid sequence of a Protein.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMolecularFunction ↔ dynamic
-
Molecular function performed by this BioChemEntity; please use
PropertyValue if you want to include any evidence.
getter/setter pairinherited
- hasRepresentation ↔ dynamic
-
A common representation such as a protein sequence or chemical structure
for this entity. For images use schema.org/image.
getter/setter pairinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - isEncodedByBioChemEntity ↔ SchemaGene?
-
Another BioChemEntity encoding by this one.
getter/setter pairinherited
- isInvolvedInBiologicalProcess ↔ dynamic
-
Biological process this BioChemEntity is involved in; please use
PropertyValue if you want to include any evidence.
getter/setter pairinherited
- isLocatedInSubcellularLocation ↔ dynamic
-
Subcellular location where this BioChemEntity is located; please use
PropertyValue if you want to include any evidence.
getter/setter pairinherited
- isPartOfBioChemEntity ↔ SchemaBioChemEntity?
-
Indicates a BioChemEntity that is (in some sense) a part of this
BioChemEntity.
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- taxonomicRange ↔ dynamic
-
The taxonomic grouping of the organism that expresses, encodes, or in
some way related to the BioChemEntity.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaGene to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited