SchemaGeoShape class
The geographic shape of a place. A GeoShape can be described using several properties whose values are based on latitude/longitude pairs. Either whitespace or commas can be used to separate latitude and longitude; whitespace should be used when writing a list of several such points. See https://schema.org/GeoShape
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaStructuredValue
- SchemaGeoShape
- Implementers
Constructors
- SchemaGeoShape({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic address, dynamic addressCountry, String? box, String? circle, dynamic elevation, String? line, String? polygon, String? postalCode})
- Create a new instance of SchemaGeoShape
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- address ↔ dynamic
-
Physical address of the item.
getter/setter pair
- addressCountry ↔ dynamic
-
//en.wikipedia.org/wiki/ISO_3166-1_alpha-3) country code such as "SGP" or
a full country name such as "Singapore" can also be used.
getter/setter pair
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- box ↔ String?
-
A box is the area enclosed by the rectangle formed by two points. The
first point is the lower corner, the second point is the upper corner. A
box is expressed as two points separated by a space character.
getter/setter pair
- circle ↔ String?
-
A circle is the circular region of a specified radius centered at a
specified latitude and longitude. A circle is expressed as a pair
followed by a radius in meters.
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- elevation ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)). Values may be of the
form 'NUMBER UNIT_OF_MEASUREMENT' (e.g., '1,000 m', '3,200 ft') while
numbers alone should be assumed to be a value in meters.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - line ↔ String?
-
A line is a point-to-point path consisting of two or more points. A line
is expressed as a series of two or more point objects separated by space.
getter/setter pair
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- polygon ↔ String?
-
A polygon is the area enclosed by a point-to-point path for which the
starting and ending points are the same. A polygon is expressed as a
series of four or more space delimited points where the first and final
points are identical.
getter/setter pair
- postalCode ↔ String?
-
The postal code. For example, 94043.
getter/setter pair
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaGeoShape to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited