SchemaGeospatialGeometry class

(Eventually to be defined as) a supertype of GeoShape designed to accommodate definitions from Geo-Spatial best practices. See https://schema.org/GeospatialGeometry

Inheritance

Constructors

SchemaGeospatialGeometry({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic geoContains, dynamic geoCoveredBy, dynamic geoCovers, dynamic geoCrosses, dynamic geoDisjoint, dynamic geoEquals, dynamic geoIntersects, dynamic geoOverlaps, dynamic geoTouches, dynamic geoWithin})
Create a new instance of SchemaGeospatialGeometry

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
geoContains ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
geoCoveredBy ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
geoCovers ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
geoCrosses ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
geoDisjoint ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).)
getter/setter pair
geoEquals ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM). "Two geometries are topologically equal if their interiors intersect and no part of the interior or boundary of one geometry intersects the exterior of the other" (a symmetric relationship).
getter/setter pair
geoIntersects ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
geoOverlaps ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
geoTouches ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).)
getter/setter pair
geoWithin ↔ dynamic
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaGeospatialGeometry to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited