SchemaHackathon class

//en.wikipedia.org/wiki/Hackathon) event. See https://schema.org/Hackathon

Inheritance

Constructors

SchemaHackathon({SchemaThing? about, dynamic actor, String? additionalType, SchemaAggregateRating? aggregateRating, String? alternateName, dynamic attendee, dynamic attendees, SchemaAudience? audience, dynamic composer, dynamic contributor, dynamic description, SchemaPerson? director, String? disambiguatingDescription, String? doorTime, dynamic duration, String? endDate, SchemaEventAttendanceModeEnumeration? eventAttendanceMode, SchemaSchedule? eventSchedule, SchemaEventStatusType? eventStatus, dynamic funder, SchemaGrant? funding, SchemaOffer? hasParticipationOffer, SchemaOffer? hasSponsorshipOffer, dynamic identifier, dynamic image, dynamic inLanguage, bool? isAccessibleForFree, dynamic keywords, dynamic location, dynamic mainEntityOfPage, int? maximumAttendeeCapacity, int? maximumPhysicalAttendeeCapacity, int? maximumVirtualAttendeeCapacity, String? name, dynamic offers, dynamic organizer, dynamic owner, dynamic performer, dynamic performers, SchemaAction? potentialAction, String? previousStartDate, SchemaCreativeWork? recordedIn, int? remainingAttendeeCapacity, SchemaReview? review, String? sameAs, dynamic sponsor, String? startDate, SchemaEvent? subEvent, SchemaEvent? subEvents, dynamic subjectOf, SchemaEvent? superEvent, dynamic translator, String? typicalAgeRange, String? url, SchemaCreativeWork? workFeatured, SchemaCreativeWork? workPerformed})
Create a new instance of SchemaHackathon

Properties

about ↔ SchemaThing?
The subject matter of an object.
getter/setter pairinherited
actor ↔ dynamic
An actor (individual or a group), e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.
getter/setter pairinherited
additionalType ↔ String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
aggregateRating ↔ SchemaAggregateRating?
The overall rating, based on a collection of reviews or ratings, of the item.
getter/setter pairinherited
alternateName ↔ String?
An alias for the item.
getter/setter pairinherited
attendee ↔ dynamic
A person or organization attending the event.
getter/setter pairinherited
attendees ↔ dynamic
A person attending the event.
getter/setter pairinherited
audience ↔ SchemaAudience?
An intended audience, i.e. a group for whom something was created.
getter/setter pairinherited
composer ↔ dynamic
The person or organization who wrote a composition, or who is the composer of a work performed at some event.
getter/setter pairinherited
contributor ↔ dynamic
A secondary contributor to the CreativeWork or Event.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
director ↔ SchemaPerson?
A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.
getter/setter pairinherited
disambiguatingDescription ↔ String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
doorTime ↔ String?
The time admission will commence.
getter/setter pairinherited
duration ↔ dynamic
//en.wikipedia.org/wiki/ISO_8601).
getter/setter pairinherited
endDate ↔ String?
//en.wikipedia.org/wiki/ISO_8601)).
getter/setter pairinherited
eventAttendanceMode ↔ SchemaEventAttendanceModeEnumeration?
The eventAttendanceMode of an event indicates whether it occurs online, offline, or a mix.
getter/setter pairinherited
eventSchedule ↔ SchemaSchedule?
Associates an SchemaEvent with a SchemaSchedule. There are circumstances where it is preferable to share a schedule for a series of repeating events rather than data on the individual events themselves. For example, a website or application might prefer to publish a schedule for a weekly gym class rather than provide data on every event. A schedule could be processed by applications to add forthcoming events to a calendar. An SchemaEvent that is associated with a SchemaSchedule using this property should not have SchemastartDate or SchemaendDate properties. These are instead defined within the associated SchemaSchedule, this avoids any ambiguity for clients using the data. The property might have repeated values to specify different schedules, e.g. for different months or seasons.
getter/setter pairinherited
eventStatus ↔ SchemaEventStatusType?
An eventStatus of an event represents its status; particularly useful when an event is cancelled or rescheduled.
getter/setter pairinherited
funder ↔ dynamic
A person or organization that supports (sponsors) something through some kind of financial contribution.
getter/setter pairinherited
funding ↔ SchemaGrant?
A SchemaGrant that directly or indirectly provide funding or sponsorship for this item. See also SchemaownershipFundingInfo.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasParticipationOffer ↔ SchemaOffer?
An offer to participate in the event, for example, Call for Proposals, Call for Speakers, or Call for Performers.
getter/setter pairinherited
hasSponsorshipOffer ↔ SchemaOffer?
An offer to sponsor the event, for example, Sponsorship Prospectus, Sponsorship Opportunities, or Sponsor Packages.
getter/setter pairinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
inLanguage ↔ dynamic
//tools.ietf.org/html/bcp47). See also SchemaavailableLanguage.
getter/setter pairinherited
isAccessibleForFree ↔ bool?
A flag to signal that the item, event, or place is accessible for free.
getter/setter pairinherited
keywords ↔ dynamic
Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.
getter/setter pairinherited
location ↔ dynamic
The location of, for example, where an event is happening, where an organization is located, or where an action takes place.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
maximumAttendeeCapacity ↔ int?
The total number of individuals that may attend an event or venue.
getter/setter pairinherited
maximumPhysicalAttendeeCapacity ↔ int?
The maximum physical attendee capacity of an SchemaEvent whose SchemaeventAttendanceMode is SchemaOfflineEventAttendanceMode (or the offline aspects, in the case of a SchemaMixedEventAttendanceMode).
getter/setter pairinherited
maximumVirtualAttendeeCapacity ↔ int?
The maximum virtual attendee capacity of an SchemaEvent whose SchemaeventAttendanceMode is SchemaOnlineEventAttendanceMode (or the online aspects, in the case of a SchemaMixedEventAttendanceMode).
getter/setter pairinherited
name ↔ String?
The name of the item.
getter/setter pairinherited
offers ↔ dynamic
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use SchemabusinessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
getter/setter pairinherited
organizer ↔ dynamic
An organizer of an Event.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
performer ↔ dynamic
A performer at the event—for example, a presenter, musician, musical group or actor.
getter/setter pairinherited
performers ↔ dynamic
The main performer or performers of the event—for example, a presenter, musician, or actor.
getter/setter pairinherited
potentialAction ↔ SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
previousStartDate ↔ String?
Used in conjunction with eventStatus for rescheduled or cancelled events. This property contains the previously scheduled start date. For rescheduled events, the startDate property should be used for the newly scheduled start date. In the (rare) case of an event that has been postponed and rescheduled multiple times, this field may be repeated.
getter/setter pairinherited
recordedIn ↔ SchemaCreativeWork?
The CreativeWork that captured all or part of this Event.
getter/setter pairinherited
remainingAttendeeCapacity ↔ int?
The number of attendee places for an event that remain unallocated.
getter/setter pairinherited
review ↔ SchemaReview?
A review of the item.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameAs ↔ String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
A person or organization that supports a thing through a pledge, promise, or financial contribution. E.g. a sponsor of a Medical Study or a corporate sponsor of an event.
getter/setter pairinherited
startDate ↔ String?
//en.wikipedia.org/wiki/ISO_8601)).
getter/setter pairinherited
subEvent ↔ SchemaEvent?
An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference.
getter/setter pairinherited
subEvents ↔ SchemaEvent?
Events that are a part of this event. For example, a conference event includes many presentations, each subEvents of the conference.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
superEvent ↔ SchemaEvent?
An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent.
getter/setter pairinherited
translator ↔ dynamic
Organization or person who adapts a creative work to different languages, regional differences and technical requirements of a target market, or that translates during some event.
getter/setter pairinherited
typicalAgeRange ↔ String?
The typical expected age range, e.g. '7-9', '11-'.
getter/setter pairinherited
url ↔ String?
URL of the item.
getter/setter pairinherited
workFeatured ↔ SchemaCreativeWork?
A work featured in some event, e.g. exhibited in an ExhibitionEvent. Specific subproperties are available for workPerformed (e.g. a play), or a workPresented (a Movie at a ScreeningEvent).
getter/setter pairinherited
workPerformed ↔ SchemaCreativeWork?
A work performed in some event, for example a play performed in a TheaterEvent.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → Map<String, dynamic>
Serialize SchemaHackathon to JSON-LD
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited