aggregateElement property
Indicates a prototype of the elements in the list that is used to hold aggregate information (ratings, offers, etc.).
Implementation
@override
SchemaThing? aggregateElement;
Indicates a prototype of the elements in the list that is used to hold aggregate information (ratings, offers, etc.).
@override
SchemaThing? aggregateElement;