securityClearanceRequirement property
A description of any security clearance requirements of the job.
Implementation
String? securityClearanceRequirement;
A description of any security clearance requirements of the job.
String? securityClearanceRequirement;