embedUrl property

  1. @override
String? embedUrl
getter/setter pairoverride

A URL pointing to a player for a specific video. In general, this is the information in the src element of an embed tag and should not be the same as the content of the loc tag.

Implementation

@override
String? embedUrl;