SchemaMass class

Properties that take Mass as values are of the form '<Number> <Mass unit of measure>'. E.g., '7 kg'. See https://schema.org/Mass

Inheritance

Constructors

SchemaMass()
Create a new instance of SchemaMass

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaMass to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited