SchemaMeasurementMethodEnum enum

Enumeration(s) for use with SchemameasurementMethod. See https://schema.org/MeasurementMethodEnum

Inheritance
Implemented types
Available extensions

Values

exampleMeasurementMethodEnum → const SchemaMeasurementMethodEnum

An example SchemaMeasurementMethodEnum (to remove when real enums are added).

const SchemaMeasurementMethodEnum('https://schema.org/MeasurementMethodEnum')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Enum value as a string
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → String
Serialize SchemaMeasurementMethodEnum to JSON-LD
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SchemaMeasurementMethodEnum>
A constant List of the values in this enum, in order of their declaration.