legalStatus property
The drug or supplement's legal status, including any controlled substance schedules that apply.
Supported types: SchemaDrugLegalStatus, SchemaMedicalEnumeration, String
Implementation
@override
dynamic legalStatus;
The drug or supplement's legal status, including any controlled substance schedules that apply.
Supported types: SchemaDrugLegalStatus, SchemaMedicalEnumeration, String
@override
dynamic legalStatus;