recognizingAuthority property
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
Implementation
@override
SchemaOrganization? recognizingAuthority;
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
@override
SchemaOrganization? recognizingAuthority;