SchemaMedicalCondition class

Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc. See https://schema.org/MedicalCondition

Inheritance
Implementers

Constructors

SchemaMedicalCondition({String? additionalType, String? alternateName, SchemaMedicalCode? code, dynamic description, String? disambiguatingDescription, SchemaGrant? funding, SchemaMedicalGuideline? guideline, dynamic identifier, dynamic image, dynamic legalStatus, dynamic mainEntityOfPage, SchemaMedicineSystem? medicineSystem, String? name, dynamic owner, SchemaAction? potentialAction, SchemaOrganization? recognizingAuthority, SchemaMedicalSpecialty? relevantSpecialty, String? sameAs, SchemaMedicalStudy? study, dynamic subjectOf, String? url, dynamic associatedAnatomy, SchemaMedicalCause? cause, SchemaDDxElement? differentialDiagnosis, SchemaDrug? drug, String? epidemiology, String? expectedPrognosis, String? naturalProgression, String? pathophysiology, String? possibleComplication, dynamic possibleTreatment, SchemaMedicalTherapy? primaryPrevention, SchemaMedicalRiskFactor? riskFactor, dynamic secondaryPrevention, SchemaMedicalSignOrSymptom? signOrSymptom, SchemaMedicalConditionStage? stage, dynamic status, SchemaMedicalTest? typicalTest})
Create a new instance of SchemaMedicalCondition

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
associatedAnatomy ↔ dynamic
The anatomy of the underlying organ system or structures associated with this entity.
getter/setter pair
cause SchemaMedicalCause?
The cause of a medical condition.
getter/setter pair
code SchemaMedicalCode?
A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
differentialDiagnosis SchemaDDxElement?
One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient.
getter/setter pair
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
drug SchemaDrug?
Specifying a drug or medicine used in a medication procedure.
getter/setter pair
epidemiology String?
The characteristics of associated patients, such as age, gender, race etc.
getter/setter pair
expectedPrognosis String?
The likely outcome in either the short term or long term of the medical condition.
getter/setter pair
funding SchemaGrant?
A SchemaGrant that directly or indirectly provide funding or sponsorship for this item. See also SchemaownershipFundingInfo.
getter/setter pairinherited
guideline SchemaMedicalGuideline?
A medical guideline related to this entity.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
legalStatus ↔ dynamic
The drug or supplement's legal status, including any controlled substance schedules that apply.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
medicineSystem SchemaMedicineSystem?
The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
naturalProgression String?
The expected progression of the condition if it is not treated and allowed to progress naturally.
getter/setter pair
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
pathophysiology String?
Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.
getter/setter pair
possibleComplication String?
A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc.
getter/setter pair
possibleTreatment ↔ dynamic
A possible treatment to address this condition, sign or symptom.
getter/setter pair
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
primaryPrevention SchemaMedicalTherapy?
A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination.
getter/setter pair
recognizingAuthority SchemaOrganization?
If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
getter/setter pairinherited
relevantSpecialty SchemaMedicalSpecialty?
If applicable, a medical specialty in which this entity is relevant.
getter/setter pairinherited
riskFactor SchemaMedicalRiskFactor?
A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age, coexisting condition.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
secondaryPrevention ↔ dynamic
A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition.
getter/setter pair
signOrSymptom SchemaMedicalSignOrSymptom?
A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experience of the medical condition.
getter/setter pair
stage SchemaMedicalConditionStage?
The stage of the condition, if applicable.
getter/setter pair
status ↔ dynamic
The status of the study (enumerated).
getter/setter pair
study SchemaMedicalStudy?
A medical study or trial related to this entity.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
typicalTest SchemaMedicalTest?
A medical test typically performed given this condition.
getter/setter pair
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaMedicalCondition to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited