hasTierRequirement property

dynamic hasTierRequirement
getter/setter pair

a CreditCard if the tier requires sign up for a credit card, A UnitPriceSpecification if the user is required to pay a (periodic) fee, or a MonetaryAmount if the user needs to spend a minimum amount to join the tier. If a tier is free to join then this property does not need to be specified.

Supported types: SchemaCreditCard, SchemaMonetaryAmount, String, SchemaUnitPriceSpecification

Implementation

dynamic hasTierRequirement;