additionalProperty property

  1. @override
SchemaPropertyValue? additionalProperty
getter/setter pairoverride

//schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.

Implementation

@override
SchemaPropertyValue? additionalProperty;