SchemaOrder class

An order is a confirmation of a transaction (a receipt), which can contain multiple line items, each represented by an Offer that has been accepted by the customer. See https://schema.org/Order

Inheritance

Constructors

SchemaOrder({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, SchemaOffer? acceptedOffer, SchemaPostalAddress? billingAddress, dynamic broker, String? confirmationNumber, dynamic customer, dynamic discount, String? discountCode, String? discountCurrency, bool? isGift, dynamic merchant, String? orderDate, SchemaParcelDelivery? orderDelivery, String? orderNumber, SchemaOrderStatus? orderStatus, dynamic orderedItem, SchemaInvoice? partOfInvoice, String? paymentDue, String? paymentDueDate, dynamic paymentMethod, String? paymentMethodId, String? paymentUrl, dynamic seller})
Create a new instance of SchemaOrder

Properties

acceptedOffer ↔ SchemaOffer?
The offer(s) -- e.g., product, quantity and price combinations -- included in the order.
getter/setter pair
additionalType ↔ String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName ↔ String?
An alias for the item.
getter/setter pairinherited
billingAddress ↔ SchemaPostalAddress?
The billing address for the order.
getter/setter pair
broker ↔ dynamic
An entity that arranges for an exchange between a buyer and a seller. In most cases a broker never acquires or releases ownership of a product or service involved in an exchange. If it is not clear whether an entity is a broker, seller, or buyer, the latter two terms are preferred.
getter/setter pair
confirmationNumber ↔ String?
A number that confirms the given order or payment has been received.
getter/setter pair
customer ↔ dynamic
Party placing the order or paying the invoice.
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription ↔ String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
discount ↔ dynamic
Any discount applied (to an Order).
getter/setter pair
discountCode ↔ String?
Code used to redeem a discount.
getter/setter pair
discountCurrency ↔ String?
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
isGift ↔ bool?
Indicates whether the offer was accepted as a gift for someone other than the buyer.
getter/setter pair
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
merchant ↔ dynamic
'merchant' is an out-dated term for 'seller'.
getter/setter pair
name ↔ String?
The name of the item.
getter/setter pairinherited
orderDate ↔ String?
Date order was placed.
getter/setter pair
orderDelivery ↔ SchemaParcelDelivery?
The delivery of the parcel related to this order or order item.
getter/setter pair
orderedItem ↔ dynamic
The item ordered.
getter/setter pair
orderNumber ↔ String?
The identifier of the transaction.
getter/setter pair
orderStatus ↔ SchemaOrderStatus?
The current status of the order.
getter/setter pair
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
partOfInvoice ↔ SchemaInvoice?
The order is being paid as part of the referenced Invoice.
getter/setter pair
paymentDue ↔ String?
The date that payment is due.
getter/setter pair
paymentDueDate ↔ String?
The date that payment is due.
getter/setter pair
paymentMethod ↔ dynamic
The name of the credit card or other method of payment for the order.
getter/setter pair
paymentMethodId ↔ String?
An identifier for the method of payment used (e.g. the last 4 digits of the credit card).
getter/setter pair
paymentUrl ↔ String?
The URL for sending a payment.
getter/setter pair
potentialAction ↔ SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameAs ↔ String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
seller ↔ dynamic
An entity which offers (sells / leases / lends / loans) the services / goods. A seller may also be a provider.
getter/setter pair
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url ↔ String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → Map<String, dynamic>
Serialize SchemaOrder to JSON-LD
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited