SchemaOrderItem class

An order item is a line of an order. It includes the quantity and shipping details of a bought offer. See https://schema.org/OrderItem

Inheritance

Constructors

SchemaOrderItem({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, SchemaParcelDelivery? orderDelivery, String? orderItemNumber, SchemaOrderStatus? orderItemStatus, dynamic orderQuantity, dynamic orderedItem})
Create a new instance of SchemaOrderItem

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
orderDelivery SchemaParcelDelivery?
The delivery of the parcel related to this order or order item.
getter/setter pair
orderedItem ↔ dynamic
The item ordered.
getter/setter pair
orderItemNumber String?
The identifier of the order item.
getter/setter pair
orderItemStatus SchemaOrderStatus?
The current status of the order item.
getter/setter pair
orderQuantity ↔ dynamic
The number of the item ordered. If the property is not set, assume the quantity is one.
getter/setter pair
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaOrderItem to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited