SchemaOrganization class
An organization such as a school, NGO, corporation, club, etc. See https://schema.org/Organization
- Inheritance
-
- Object
- SchemaThing
- SchemaOrganization
- Implementers
- SchemaAirline
- SchemaConsortium
- SchemaCooperative
- SchemaCorporation
- SchemaEducationalOrganization
- SchemaFundingScheme
- SchemaGovernmentOrganization
- SchemaLibrarySystem
- SchemaLocalBusiness
- SchemaMedicalOrganization
- SchemaNewsMediaOrganization
- SchemaNGO
- SchemaOnlineBusiness
- SchemaPerformingGroup
- SchemaPoliticalParty
- SchemaProject
- SchemaResearchOrganization
- SchemaSearchRescueOrganization
- SchemaSportsOrganization
- SchemaWorkersUnion
Constructors
- SchemaOrganization({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic acceptedPaymentMethod, dynamic actionableFeedbackPolicy, dynamic address, SchemaInteractionCounter? agentInteractionStatistic, SchemaAggregateRating? aggregateRating, SchemaPerson? alumni, dynamic areaServed, String? award, String? awards, dynamic brand, SchemaCertification? companyRegistration, SchemaContactPoint? contactPoint, SchemaContactPoint? contactPoints, dynamic correctionsPolicy, SchemaOrganization? department, String? dissolutionDate, dynamic diversityPolicy, dynamic diversityStaffingReport, String? duns, String? email, SchemaPerson? employee, SchemaPerson? employees, dynamic ethicsPolicy, SchemaEvent? event, SchemaEvent? events, String? faxNumber, dynamic founder, SchemaPerson? founders, String? foundingDate, SchemaPlace? foundingLocation, dynamic funder, SchemaGrant? funding, String? globalLocationNumber, SchemaCertification? hasCertification, SchemaCredential? hasCredential, String? hasGS1DigitalLink, SchemaMemberProgram? hasMemberProgram, SchemaMerchantReturnPolicy? hasMerchantReturnPolicy, SchemaOfferCatalog? hasOfferCatalog, SchemaPlace? hasPOS, SchemaShippingService? hasShippingService, SchemaInteractionCounter? interactionStatistic, String? isicV4, String? iso6523Code, dynamic keywords, dynamic knowsAbout, dynamic knowsLanguage, SchemaPostalAddress? legalAddress, String? legalName, SchemaPerson? legalRepresentative, String? leiCode, dynamic location, dynamic logo, SchemaOffer? makesOffer, dynamic member, dynamic memberOf, dynamic members, String? naics, SchemaNonprofitType? nonprofitStatus, SchemaQuantitativeValue? numberOfEmployees, dynamic ownershipFundingInfo, SchemaThing? owns, SchemaOrganization? parentOrganization, dynamic publishingPrinciples, SchemaReview? review, SchemaReview? reviews, SchemaDemand? seeks, dynamic serviceArea, dynamic skills, String? slogan, dynamic sponsor, SchemaOrganization? subOrganization, String? taxID, String? telephone, dynamic unnamedSourcesPolicy, String? vatID})
- Create a new instance of SchemaOrganization
Properties
- acceptedPaymentMethod ↔ dynamic
-
The payment method(s) that are accepted in general by an organization, or
for some specific demand or offer.
getter/setter pair
- actionableFeedbackPolicy ↔ dynamic
-
For a SchemaNewsMediaOrganization or other news-related
SchemaOrganization, a statement about public engagement activities (for
news media, the newsroom’s), including involving the public - digitally
or otherwise -- in coverage decisions, reporting and activities after
publication.
getter/setter pair
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- address ↔ dynamic
-
Physical address of the item.
getter/setter pair
- agentInteractionStatistic ↔ SchemaInteractionCounter?
-
The number of completed interactions for this entity, in a particular
role (the 'agent'), in a particular action (indicated in the statistic),
and in a particular context (i.e. interactionService).
getter/setter pair
- aggregateRating ↔ SchemaAggregateRating?
-
The overall rating, based on a collection of reviews or ratings, of the
item.
getter/setter pair
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- alumni ↔ SchemaPerson?
-
Alumni of an organization.
getter/setter pair
- areaServed ↔ dynamic
-
The geographic area where a service or offered item is provided.
getter/setter pair
- award ↔ String?
-
An award won by or for this item.
getter/setter pair
- awards ↔ String?
-
Awards won by or for this item.
getter/setter pair
- brand ↔ dynamic
-
The brand(s) associated with a product or service, or the brand(s)
maintained by an organization or business person.
getter/setter pair
- companyRegistration ↔ SchemaCertification?
-
The official registration information of a business including the
organization that issued it such as Company House or Chamber of Commerce
in form of a Certification.
getter/setter pair
- contactPoint ↔ SchemaContactPoint?
-
A contact point for a person or organization.
getter/setter pair
- contactPoints ↔ SchemaContactPoint?
-
A contact point for a person or organization.
getter/setter pair
- correctionsPolicy ↔ dynamic
-
For an SchemaOrganization (e.g. SchemaNewsMediaOrganization), a
statement describing (in news media, the newsroom’s) disclosure and
correction policy for errors.
getter/setter pair
- department ↔ SchemaOrganization?
-
a store with a pharmacy, or a bakery with a cafe.
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- dissolutionDate ↔ String?
-
The date that this organization was dissolved.
getter/setter pair
- diversityPolicy ↔ dynamic
-
Statement on diversity policy by an SchemaOrganization e.g. a
SchemaNewsMediaOrganization. For a SchemaNewsMediaOrganization, a
statement describing the newsroom’s diversity policy on both staffing and
sources, typically providing staffing data.
getter/setter pair
- diversityStaffingReport ↔ dynamic
-
For an SchemaOrganization (often but not necessarily a
SchemaNewsMediaOrganization), a report on staffing diversity issues. In
a news context this might be for example ASNE or RTDNA (US) reports, or
self-reported.
getter/setter pair
- duns ↔ String?
-
The Dun & Bradstreet DUNS number for identifying an organization or
business person.
getter/setter pair
- email ↔ String?
-
Email address.
getter/setter pair
- employee ↔ SchemaPerson?
-
Someone working for this organization.
getter/setter pair
- employees ↔ SchemaPerson?
-
People working for this organization.
getter/setter pair
- ethicsPolicy ↔ dynamic
-
Statement about ethics policy, e.g. of a SchemaNewsMediaOrganization
regarding journalistic and publishing practices, or of a
SchemaRestaurant, a page describing food source policies. In the case
of a SchemaNewsMediaOrganization, an ethicsPolicy is typically a
statement describing the personal, organizational, and corporate
standards of behavior expected by the organization.
getter/setter pair
- event ↔ SchemaEvent?
-
Upcoming or past event associated with this place, organization, or
action.
getter/setter pair
- events ↔ SchemaEvent?
-
Upcoming or past events associated with this place or organization.
getter/setter pair
- faxNumber ↔ String?
-
The fax number.
getter/setter pair
- founder ↔ dynamic
-
A person or organization who founded this organization.
getter/setter pair
- founders ↔ SchemaPerson?
-
A person who founded this organization.
getter/setter pair
- foundingDate ↔ String?
-
The date that this organization was founded.
getter/setter pair
- foundingLocation ↔ SchemaPlace?
-
The place where the Organization was founded.
getter/setter pair
- funder ↔ dynamic
-
A person or organization that supports (sponsors) something through some
kind of financial contribution.
getter/setter pair
- funding ↔ SchemaGrant?
-
A SchemaGrant that directly or indirectly provide funding or
sponsorship for this item. See also
SchemaownershipFundingInfo.getter/setter pair - globalLocationNumber ↔ String?
-
//www.gs1.org/gln) (GLN, sometimes also referred to as International
Location Number or ILN) of the respective organization, person, or place.
The GLN is a 13-digit number used to identify parties and physical
locations.
getter/setter pair
- hasCertification ↔ SchemaCertification?
-
Certification information about a product, organization, service, place,
or person.
getter/setter pair
- hasCredential ↔ SchemaCredential?
-
A credential awarded to the Person or Organization.
getter/setter pair
- hasGS1DigitalLink ↔ String?
-
- A Digital Link that contains a serial number (AI
21) should only be present on instances of [SchemaIndividualProduct]- A Digital Link that contains a lot number (AI
10) should be annotated as [SchemaSomeProducts] if only products from that lot are sold, or [SchemaIndividualProduct] if there is only a specific product.- A Digital Link that contains a global model number (AI
8013) should be attached to a [SchemaProduct] or a [SchemaProductModel].getter/setter pair - A Digital Link that contains a serial number (AI
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMemberProgram ↔ SchemaMemberProgram?
-
MemberProgram offered by an Organization, for example an eCommerce
merchant or an airline.
getter/setter pair
- hasMerchantReturnPolicy ↔ SchemaMerchantReturnPolicy?
-
Specifies a MerchantReturnPolicy that may be applicable.
getter/setter pair
- hasOfferCatalog ↔ SchemaOfferCatalog?
-
Indicates an OfferCatalog listing for this Organization, Person, or
Service.
getter/setter pair
- hasPOS ↔ SchemaPlace?
-
Points-of-Sales operated by the organization or person.
getter/setter pair
- hasShippingService ↔ SchemaShippingService?
-
Specification of a shipping service offered by the organization.
getter/setter pair
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - interactionStatistic ↔ SchemaInteractionCounter?
-
The number of interactions for the CreativeWork using the WebSite or
SoftwareApplication. The most specific child type of InteractionCounter
should be used.
getter/setter pair
- isicV4 ↔ String?
-
The International Standard of Industrial Classification of All Economic
Activities (ISIC), Revision 4 code for a particular organization,
business person, or place.
getter/setter pair
- iso6523Code ↔ String?
-
//schema.org/taxID), as ISO identifiers are less ambiguous.
getter/setter pair
- keywords ↔ dynamic
-
Keywords or tags used to describe some item. Multiple textual entries in
a keywords list are typically delimited by commas, or by repeating the
property.
getter/setter pair
- knowsAbout ↔ dynamic
-
Of a SchemaPerson, and less typically of an SchemaOrganization, to
indicate a topic that is known about - suggesting possible expertise but
not implying it. We do not distinguish skill levels here, or relate this
to educational content, events, objectives or SchemaJobPosting
descriptions.
getter/setter pair
- knowsLanguage ↔ dynamic
-
//tools.ietf.org/html/bcp47).
getter/setter pair
- legalAddress ↔ SchemaPostalAddress?
-
The legal address of an organization which acts as the officially
registered address used for legal and tax purposes. The legal address can
be different from the place of operations of a business and other
addresses can be part of an organization.
getter/setter pair
- legalName ↔ String?
-
The official name of the organization, e.g. the registered company name.
getter/setter pair
- legalRepresentative ↔ SchemaPerson?
-
One or multiple persons who represent this organization legally such as
CEO or sole administrator.
getter/setter pair
- leiCode ↔ String?
-
An organization identifier that uniquely identifies a legal entity as
defined in ISO 17442.
getter/setter pair
- location ↔ dynamic
-
The location of, for example, where an event is happening, where an
organization is located, or where an action takes place.
getter/setter pair
- logo ↔ dynamic
-
An associated logo.
getter/setter pair
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- makesOffer ↔ SchemaOffer?
-
A pointer to products or services offered by the organization or person.
getter/setter pair
- member ↔ dynamic
-
A member of an Organization or a ProgramMembership. Organizations can be
members of organizations; ProgramMembership is typically for individuals.
getter/setter pair
- memberOf ↔ dynamic
-
An Organization (or ProgramMembership) to which this Person or
Organization belongs.
getter/setter pair
- members ↔ dynamic
-
A member of this organization.
getter/setter pair
- naics ↔ String?
-
The North American Industry Classification System (NAICS) code for a
particular organization or business person.
getter/setter pair
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- nonprofitStatus ↔ SchemaNonprofitType?
-
nonprofitStatus indicates the legal status of a non-profit organization
in its primary place of business.
getter/setter pair
- numberOfEmployees ↔ SchemaQuantitativeValue?
-
The number of employees in an organization, e.g. business.
getter/setter pair
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- ownershipFundingInfo ↔ dynamic
-
For an SchemaOrganization (often but not necessarily a
SchemaNewsMediaOrganization), a description of organizational ownership
structure; funding and grants. In a news/media setting, this is with
particular reference to editorial independence. Note that the
Schemafunderis also available and can be used to make basic funder information machine-readable.getter/setter pair - owns ↔ SchemaThing?
-
Things owned by the organization or person.
getter/setter pair
- parentOrganization ↔ SchemaOrganization?
-
The larger organization that this organization is a
SchemasubOrganizationof, if any.getter/setter pair - potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- publishingPrinciples ↔ dynamic
-
The publishingPrinciples property indicates (typically via
SchemaURL) a document describing the editorial principles of an SchemaOrganization (or individual, e.g. a SchemaPerson writing a blog) that relate to their activities as a publisher, e.g. ethics or diversity policies. When applied to a SchemaCreativeWork (e.g. SchemaNewsArticle) the principles are those of the party primarily responsible for the creation of the SchemaCreativeWork.getter/setter pair - review ↔ SchemaReview?
-
A review of the item.
getter/setter pair
- reviews ↔ SchemaReview?
-
Review of the item.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- seeks ↔ SchemaDemand?
-
A pointer to products or services sought by the organization or person
(demand).
getter/setter pair
- serviceArea ↔ dynamic
-
The geographic area where the service is provided.
getter/setter pair
- skills ↔ dynamic
-
A statement of knowledge, skill, ability, task or any other assertion
expressing a competency that is either claimed by a person, an
organization or desired or required to fulfill a role or to work in an
occupation.
getter/setter pair
- slogan ↔ String?
-
A slogan or motto associated with the item.
getter/setter pair
- sponsor ↔ dynamic
-
A person or organization that supports a thing through a pledge, promise,
or financial contribution. E.g. a sponsor of a Medical Study or a
corporate sponsor of an event.
getter/setter pair
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- subOrganization ↔ SchemaOrganization?
-
the more specific 'department' property.
getter/setter pair
- taxID ↔ String?
-
The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US
or the CIF/NIF in Spain.
getter/setter pair
- telephone ↔ String?
-
The telephone number.
getter/setter pair
- unnamedSourcesPolicy ↔ dynamic
-
For an SchemaOrganization (typically a SchemaNewsMediaOrganization),
a statement about policy on use of unnamed sources and the decision
process required.
getter/setter pair
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
- vatID ↔ String?
-
The value-added Tax ID of the organization or person with national prefix
(for example IT123456789). Can also be described as
Schemaiso6523Codewith proper prefix.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaOrganization to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited