events property
Upcoming or past events associated with this place or organization.
Implementation
@Deprecated('Use [event]. See https://schema.org/events')
SchemaEvent? events;
Upcoming or past events associated with this place or organization.
@Deprecated('Use [event]. See https://schema.org/events')
SchemaEvent? events;