hasShippingService property
Specification of a shipping service offered by the organization.
Implementation
SchemaShippingService? hasShippingService;
Specification of a shipping service offered by the organization.
SchemaShippingService? hasShippingService;