SchemaPermit class

A permit issued by an organization, e.g. a parking pass. See https://schema.org/Permit

Inheritance
Implementers

Constructors

SchemaPermit({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, SchemaOrganization? issuedBy, SchemaService? issuedThrough, SchemaAudience? permitAudience, SchemaDuration? validFor, String? validFrom, SchemaAdministrativeArea? validIn, String? validUntil})
Create a new instance of SchemaPermit

Properties

additionalType ↔ String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName ↔ String?
An alias for the item.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription ↔ String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
issuedBy ↔ SchemaOrganization?
The organization issuing the item, for example a SchemaPermit, SchemaTicket, or SchemaCertification.
getter/setter pair
issuedThrough ↔ SchemaService?
The service through which the permit was granted.
getter/setter pair
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name ↔ String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
permitAudience ↔ SchemaAudience?
The target audience for this permit.
getter/setter pair
potentialAction ↔ SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sameAs ↔ String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url ↔ String?
URL of the item.
getter/setter pairinherited
validFor ↔ SchemaDuration?
The duration of validity of a permit or similar thing.
getter/setter pair
validFrom ↔ String?
The date when the item becomes valid.
getter/setter pair
validIn ↔ SchemaAdministrativeArea?
The geographic area where the item is valid. Applies for example to a SchemaPermit, a SchemaCertification, or an SchemaEducationalOccupationalCredential.
getter/setter pair
validUntil ↔ String?
The date when the item is no longer valid.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() → Map<String, dynamic>
Serialize SchemaPermit to JSON-LD
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited