gender property
dynamic
gender
getter/setter pair
//schema.org/Female may be used, text strings are also acceptable for
people who are not a binary gender. The Schemagender property can also
be used in an extended sense to cover e.g. the gender of sports teams. As
with the gender of individuals, we do not try to enumerate all
possibilities. A mixed-gender SchemaSportsTeam can be indicated with a
text value of "Mixed".
Supported types: SchemaGenderType, String
Implementation
dynamic gender;