SchemaPhysicalExam class
A type of physical examination of a patient performed by a physician. See https://schema.org/PhysicalExam
- Inheritance
-
- Object
- SchemaThing
- SchemaMedicalEntity
- SchemaMedicalProcedure
- SchemaPhysicalExam
- Implemented types
Constructors
- SchemaPhysicalExam({String? additionalType, String? alternateName, String? bodyLocation, SchemaMedicalCode? code, dynamic description, String? disambiguatingDescription, String? followup, SchemaGrant? funding, SchemaMedicalGuideline? guideline, String? howPerformed, dynamic identifier, dynamic image, dynamic legalStatus, dynamic mainEntityOfPage, SchemaMedicineSystem? medicineSystem, String? name, dynamic owner, SchemaAction? potentialAction, dynamic preparation, SchemaMedicalProcedureType? procedureType, SchemaOrganization? recognizingAuthority, SchemaMedicalSpecialty? relevantSpecialty, String? sameAs, dynamic status, SchemaMedicalStudy? study, dynamic subjectOf, String? url})
- Create a new instance of SchemaPhysicalExam
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- bodyLocation ↔ String?
-
Location in the body of the anatomical structure.
getter/setter pairinherited
- code ↔ SchemaMedicalCode?
-
A medical code for the entity, taken from a controlled vocabulary or
ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- followup ↔ String?
-
Typical or recommended followup care after the procedure is performed.
getter/setter pairinherited
- funding ↔ SchemaGrant?
-
A SchemaGrant that directly or indirectly provide funding or
sponsorship for this item. See also
SchemaownershipFundingInfo.getter/setter pairinherited - guideline ↔ SchemaMedicalGuideline?
-
A medical guideline related to this entity.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- howPerformed ↔ String?
-
How the procedure is performed.
getter/setter pairinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - legalStatus ↔ dynamic
-
The drug or supplement's legal status, including any controlled substance
schedules that apply.
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- medicineSystem ↔ SchemaMedicineSystem?
-
The system of medicine that includes this MedicalEntity, for example
'evidence-based', 'homeopathic', 'chiropractic', etc.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- preparation ↔ dynamic
-
Typical preparation that a patient must undergo before having the
procedure performed.
getter/setter pairinherited
- procedureType ↔ SchemaMedicalProcedureType?
-
The type of procedure, for example Surgical, Noninvasive, or
Percutaneous.
getter/setter pairinherited
- recognizingAuthority ↔ SchemaOrganization?
-
If applicable, the organization that officially recognizes this entity as
part of its endorsed system of medicine.
getter/setter pairinherited
- relevantSpecialty ↔ SchemaMedicalSpecialty?
-
If applicable, a medical specialty in which this entity is relevant.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- status ↔ dynamic
-
The status of the study (enumerated).
getter/setter pairinherited
- study ↔ SchemaMedicalStudy?
-
A medical study or trial related to this entity.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaPhysicalExam to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited