SchemaProductModel class

A datasheet or vendor specification of a product (in the sense of a prototypical description). See https://schema.org/ProductModel

Inheritance

Constructors

SchemaProductModel({SchemaPropertyValue? additionalProperty, String? additionalType, SchemaAggregateRating? aggregateRating, String? alternateName, String? asin, SchemaAudience? audience, String? award, String? awards, dynamic brand, dynamic category, String? color, dynamic colorSwatch, String? countryOfAssembly, String? countryOfLastProcessing, SchemaCountry? countryOfOrigin, dynamic depth, dynamic description, String? disambiguatingDescription, SchemaPlace? displayLocation, SchemaGrant? funding, String? gtin, String? gtin12, String? gtin13, String? gtin14, String? gtin8, SchemaAdultOrientedEnumeration? hasAdultConsideration, SchemaCertification? hasCertification, SchemaEnergyConsumptionDetails? hasEnergyConsumptionDetails, String? hasGS1DigitalLink, SchemaQuantitativeValue? hasMeasurement, SchemaMerchantReturnPolicy? hasMerchantReturnPolicy, dynamic height, dynamic identifier, dynamic image, String? inProductGroupWithID, SchemaProduct? isAccessoryOrSparePartFor, SchemaProduct? isConsumableFor, bool? isFamilyFriendly, dynamic isRelatedTo, dynamic isSimilarTo, dynamic isVariantOf, SchemaOfferItemCondition? itemCondition, dynamic keywords, dynamic mainEntityOfPage, SchemaOrganization? manufacturer, dynamic material, String? mobileUrl, dynamic model, String? mpn, String? name, dynamic negativeNotes, String? nsn, dynamic offers, dynamic owner, dynamic pattern, dynamic positiveNotes, SchemaAction? potentialAction, String? productID, String? productionDate, String? purchaseDate, String? releaseDate, SchemaReview? review, SchemaReview? reviews, String? sameAs, dynamic size, String? sku, String? slogan, dynamic subjectOf, String? url, dynamic weight, dynamic width, SchemaProductModel? predecessorOf, SchemaProductModel? successorOf})
Create a new instance of SchemaProductModel

Properties

additionalProperty ↔ SchemaPropertyValue?
//schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
getter/setter pairinherited
additionalType ↔ String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
aggregateRating ↔ SchemaAggregateRating?
The overall rating, based on a collection of reviews or ratings, of the item.
getter/setter pairinherited
alternateName ↔ String?
An alias for the item.
getter/setter pairinherited
asin ↔ String?
//en.wikipedia.org/wiki/Amazon_Standard_Identification_Number)'s article).
getter/setter pairinherited
audience ↔ SchemaAudience?
An intended audience, i.e. a group for whom something was created.
getter/setter pairinherited
award ↔ String?
An award won by or for this item.
getter/setter pairinherited
awards ↔ String?
Awards won by or for this item.
getter/setter pairinherited
brand ↔ dynamic
The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
getter/setter pairinherited
category ↔ dynamic
A category for the item. Greater signs or slashes can be used to informally indicate a category hierarchy.
getter/setter pairinherited
color ↔ String?
The color of the product.
getter/setter pairinherited
colorSwatch ↔ dynamic
A color swatch image, visualizing the color of a SchemaProduct. Should match the textual description specified in the Schemacolor property. This can be a URL or a fully described ImageObject.
getter/setter pairinherited
countryOfAssembly ↔ String?
The place where the product was assembled.
getter/setter pairinherited
countryOfLastProcessing ↔ String?
The place where the item (typically SchemaProduct) was last processed and tested before importation.
getter/setter pairinherited
countryOfOrigin ↔ SchemaCountry?
The country of origin of something, including products as well as creative works such as movie and TV content.
getter/setter pairinherited
depth ↔ dynamic
The depth of the item.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription ↔ String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
displayLocation ↔ SchemaPlace?
The location at which an item can be viewed or experienced in-person.
getter/setter pairinherited
funding ↔ SchemaGrant?
A SchemaGrant that directly or indirectly provide funding or sponsorship for this item. See also SchemaownershipFundingInfo.
getter/setter pairinherited
gtin ↔ String?
//www.gs1.org/standards/Digital-Link/) expresses GTINs as URLs (URIs, IRIs, etc.). Digital Links should be populated into the SchemahasGS1DigitalLink attribute.
getter/setter pairinherited
gtin12 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
gtin13 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
gtin14 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
gtin8 ↔ String?
//www.gs1.org/barcodes/technical/idkeys/gtin) for more details.
getter/setter pairinherited
hasAdultConsideration ↔ SchemaAdultOrientedEnumeration?
Used to tag an item to be intended or suitable for consumption or use by adults only.
getter/setter pairinherited
hasCertification ↔ SchemaCertification?
Certification information about a product, organization, service, place, or person.
getter/setter pairinherited
hasEnergyConsumptionDetails ↔ SchemaEnergyConsumptionDetails?
Defines the energy efficiency Category (also known as "class" or "rating") for a product according to an international energy efficiency standard.
getter/setter pairinherited
  • A Digital Link that contains a serial number (AI 21) should only be present on instances of [SchemaIndividualProduct]
  • A Digital Link that contains a lot number (AI 10) should be annotated as [SchemaSomeProducts] if only products from that lot are sold, or [SchemaIndividualProduct] if there is only a specific product.
  • A Digital Link that contains a global model number (AI 8013) should be attached to a [SchemaProduct] or a [SchemaProductModel].
  • getter/setter pairinherited
    hashCode → int
    The hash code for this object.
    no setterinherited
    hasMeasurement ↔ SchemaQuantitativeValue?
    A measurement of an item, For example, the inseam of pants, the wheel size of a bicycle, the gauge of a screw, or the carbon footprint measured for certification by an authority. Usually an exact measurement, but can also be a range of measurements for adjustable products, for example belts and ski bindings.
    getter/setter pairinherited
    hasMerchantReturnPolicy ↔ SchemaMerchantReturnPolicy?
    Specifies a MerchantReturnPolicy that may be applicable.
    getter/setter pairinherited
    height ↔ dynamic
    The height of the item.
    getter/setter pairinherited
    identifier ↔ dynamic
    The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
    getter/setter pairinherited
    image ↔ dynamic
    An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
    getter/setter pairinherited
    inProductGroupWithID ↔ String?
    Indicates the SchemaproductGroupID for a SchemaProductGroup that this product SchemaisVariantOf.
    getter/setter pairinherited
    isAccessoryOrSparePartFor ↔ SchemaProduct?
    A pointer to another product (or multiple products) for which this product is an accessory or spare part.
    getter/setter pairinherited
    isConsumableFor ↔ SchemaProduct?
    A pointer to another product (or multiple products) for which this product is a consumable.
    getter/setter pairinherited
    isFamilyFriendly ↔ bool?
    Indicates whether this content is family friendly.
    getter/setter pairinherited
    isRelatedTo ↔ dynamic
    A pointer to another, somehow related product (or multiple products).
    getter/setter pairinherited
    isSimilarTo ↔ dynamic
    A pointer to another, functionally similar product (or multiple products).
    getter/setter pairinherited
    isVariantOf ↔ dynamic
    Indicates the kind of product that this is a variant of. In the case of SchemaProductModel, this is a pointer (from a ProductModel) to a base product from which this product is a variant. It is safe to infer that the variant inherits all product features from the base model, unless defined locally. This is not transitive. In the case of a SchemaProductGroup, the group description also serves as a template, representing a set of Products that vary on explicitly defined, specific dimensions only (so it defines both a set of variants, as well as which values distinguish amongst those variants). When used with SchemaProductGroup, this property can apply to any SchemaProduct included in the group.
    getter/setter pairinherited
    itemCondition ↔ SchemaOfferItemCondition?
    A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.
    getter/setter pairinherited
    keywords ↔ dynamic
    Keywords or tags used to describe some item. Multiple textual entries in a keywords list are typically delimited by commas, or by repeating the property.
    getter/setter pairinherited
    An associated logo.
    getter/setter pairinherited
    mainEntityOfPage ↔ dynamic
    Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
    getter/setter pairinherited
    manufacturer ↔ SchemaOrganization?
    The manufacturer of the product.
    getter/setter pairinherited
    material ↔ dynamic
    A material that something is made from, e.g. leather, wool, cotton, paper.
    getter/setter pairinherited
    mobileUrl ↔ String?
    //en.wikipedia.org/wiki/Responsive_web_design) in which content can be flexibly adapted to a wide range of browsing environments. Pages and sites referenced with the long-established Schemaurl property should ideally also be usable on a wide variety of devices, including mobile phones. In most cases, it would be pointless and counter productive to attempt to update all Schemaurl markup to use SchemamobileUrl for more mobile-oriented pages. The property is intended for the case when items (primarily SchemaProduct and SchemaOffer) have extra URLs hosted on an additional "mobile site" alongside the main one. It should not be taken as an endorsement of this publication style.
    getter/setter pairinherited
    model ↔ dynamic
    The model of the product. Use with the URL of a ProductModel or a textual representation of the model identifier. The URL of the ProductModel can be from an external source. It is recommended to additionally provide strong product identifiers via the gtin8/gtin13/gtin14 and mpn properties.
    getter/setter pairinherited
    mpn ↔ String?
    The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
    getter/setter pairinherited
    name ↔ String?
    The name of the item.
    getter/setter pairinherited
    negativeNotes ↔ dynamic
    Provides negative considerations regarding something, most typically in pro/con lists for reviews (alongside SchemapositiveNotes). For symmetry
    getter/setter pairinherited
    nsn ↔ String?
    //en.wikipedia.org/wiki/NATO_Stock_Number) (nsn) of a SchemaProduct.
    getter/setter pairinherited
    offers ↔ dynamic
    An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use SchemabusinessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
    getter/setter pairinherited
    owner ↔ dynamic
    A person or organization who owns this Thing.
    getter/setter pairinherited
    pattern ↔ dynamic
    A pattern that something has, for example 'polka dot', 'striped', 'Canadian flag'. Values are typically expressed as text, although links to controlled value schemes are also supported.
    getter/setter pairinherited
    positiveNotes ↔ dynamic
    Provides positive considerations regarding something, for example product highlights or (alongside SchemanegativeNotes) pro/con lists for reviews.
    getter/setter pairinherited
    potentialAction ↔ SchemaAction?
    Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
    getter/setter pairinherited
    predecessorOf ↔ SchemaProductModel?
    A pointer from a previous, often discontinued variant of the product to its newer variant.
    getter/setter pair
    productID ↔ String?
    123-456-789" ```.
    getter/setter pairinherited
    productionDate ↔ String?
    The date of production of the item, e.g. vehicle.
    getter/setter pairinherited
    purchaseDate ↔ String?
    The date the item, e.g. vehicle, was purchased by the current owner.
    getter/setter pairinherited
    releaseDate ↔ String?
    The release date of a product or product model. This can be used to distinguish the exact variant of a product.
    getter/setter pairinherited
    review ↔ SchemaReview?
    A review of the item.
    getter/setter pairinherited
    reviews ↔ SchemaReview?
    Review of the item.
    getter/setter pairinherited
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited
    sameAs ↔ String?
    URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
    getter/setter pairinherited
    size ↔ dynamic
    A standardized size of a product or creative work, specified either through a simple textual string (for example 'XL', '32Wx34L'), a QuantitativeValue with a unitCode, or a comprehensive and structured SchemaSizeSpecification; in other cases, the Schemawidth, Schemaheight, Schemadepth and Schemaweight properties may be more applicable.
    getter/setter pairinherited
    sku ↔ String?
    The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
    getter/setter pairinherited
    slogan ↔ String?
    A slogan or motto associated with the item.
    getter/setter pairinherited
    subjectOf ↔ dynamic
    A CreativeWork or Event about this Thing.
    getter/setter pairinherited
    successorOf ↔ SchemaProductModel?
    A pointer from a newer variant of a product to its previous, often discontinued predecessor.
    getter/setter pair
    url ↔ String?
    URL of the item.
    getter/setter pairinherited
    weight ↔ dynamic
    The weight of the product or person.
    getter/setter pairinherited
    width ↔ dynamic
    The width of the item.
    getter/setter pairinherited

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJsonLd() → Map<String, dynamic>
    Serialize SchemaProductModel to JSON-LD
    override
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited