SchemaPropertyValue class
A property-value pair, e.g. representing a feature of a product or place. Use the 'name' property for the name of the property. If there is an additional human-readable version of the value, put that into the 'description' property.\n\n Always use specific schema.org properties when a) they exist and b) you can populate them. Using PropertyValue as a substitute will typically not trigger the same effect as using the original, specific property. See https://schema.org/PropertyValue
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaStructuredValue
- SchemaPropertyValue
- Implementers
Constructors
- SchemaPropertyValue({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, num? maxValue, dynamic measurementMethod, dynamic measurementTechnique, num? minValue, String? propertyID, String? unitCode, String? unitText, dynamic value, dynamic valueReference})
- Create a new instance of SchemaPropertyValue
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- maxValue ↔ num?
-
The upper value of some characteristic or property.
getter/setter pair
- measurementMethod ↔ dynamic
-
A subproperty of
SchemameasurementTechniquethat can be used for specifying specific methods, in particular via SchemaMeasurementMethodEnum.getter/setter pair - measurementTechnique ↔ dynamic
-
"mass spectrometry" or "nmr spectroscopy" or "colorimetry" or
"immunofluorescence". If the
SchemavariableMeasuredis "depression rating", theSchemameasurementTechniquecould be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".getter/setter pair - minValue ↔ num?
-
The lower value of some characteristic or property.
getter/setter pair
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- propertyID ↔ String?
-
A commonly used identifier for the characteristic represented by the
property, e.g. a manufacturer or a standard code for a property.
propertyID can be (1) a prefixed string, mainly meant to be used with
standards for product properties; (2) a site-specific, non-prefixed
string (e.g. the primary key of the property or the vendor-specific ID of
the property), or (3) a URL indicating the type of the property, either
pointing to an external vocabulary, or a Web resource that describes the
property (e.g. a glossary entry). Standards bodies should promote a
standard prefix for the identifiers of properties from their standards.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- unitCode ↔ String?
-
The unit of measurement given using the UN/CEFACT Common Code (3
characters) or a URL. Other codes than the UN/CEFACT Common Code may be
used with a prefix followed by a colon.
getter/setter pair
- unitText ↔ String?
-
A string or text indicating the unit of measurement. Useful if you cannot
provide a standard unit code for unitCode.
getter/setter pair
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
- value ↔ dynamic
-
The value of a SchemaQuantitativeValue (including SchemaObservation)
or property value node.\n\n* For SchemaQuantitativeValue and
SchemaMonetaryAmount, the recommended type for values is 'Number'.\n*
For SchemaPropertyValue, it can be 'Text', 'Number', 'Boolean', or
'StructuredValue'.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO'
(U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar
Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than
',' to indicate a decimal point. Avoid using these symbols as a
readability separator.
getter/setter pair
- valueReference ↔ dynamic
-
A secondary value that provides additional information on the original
value, e.g. a reference temperature or a type of measurement.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaPropertyValue to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited