SchemaPropertyValueSpecification class

A Property value specification. See https://schema.org/PropertyValueSpecification

Inheritance

Constructors

SchemaPropertyValueSpecification({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic defaultValue, num? maxValue, num? minValue, bool? multipleValues, bool? readonlyValue, num? stepValue, num? valueMaxLength, num? valueMinLength, String? valueName, String? valuePattern, bool? valueRequired})
Create a new instance of SchemaPropertyValueSpecification

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
defaultValue ↔ dynamic
The default value of the input. For properties that expect a literal, the default is a literal value, for properties that expect an object, it's an ID reference to one of the current values.
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
maxValue num?
The upper value of some characteristic or property.
getter/setter pair
minValue num?
The lower value of some characteristic or property.
getter/setter pair
multipleValues bool?
Whether multiple values are allowed for the property. Default is false.
getter/setter pair
name String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
readonlyValue bool?
Whether or not a property is mutable. Default is false. Specifying this for a property that also has a value makes it act similar to a "hidden" input in an HTML form.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
stepValue num?
The stepValue attribute indicates the granularity that is expected (and required) of the value in a PropertyValueSpecification.
getter/setter pair
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited
valueMaxLength num?
Specifies the allowed range for number of characters in a literal value.
getter/setter pair
valueMinLength num?
Specifies the minimum allowed range for number of characters in a literal value.
getter/setter pair
valueName String?
Indicates the name of the PropertyValueSpecification to be used in URL templates and form encoding in a manner analogous to HTML's input@name.
getter/setter pair
valuePattern String?
Specifies a regular expression for testing literal values according to the HTML spec.
getter/setter pair
valueRequired bool?
Whether the property must be filled in to complete the action. Default is false.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaPropertyValueSpecification to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited