SchemaReplyAction class
Appears generally as an origin of a ReplyAction. See https://schema.org/ReplyAction
- Inheritance
-
- Object
- SchemaThing
- SchemaAction
- SchemaInteractAction
- SchemaCommunicateAction
- SchemaReplyAction
Constructors
- SchemaReplyAction({SchemaThing? about, SchemaHowTo? actionProcess, SchemaActionStatusType? actionStatus, String? additionalType, dynamic agent, String? alternateName, dynamic description, String? disambiguatingDescription, String? endTime, SchemaThing? error, dynamic identifier, dynamic image, dynamic inLanguage, SchemaThing? instrument, SchemaLanguage? language, dynamic location, dynamic mainEntityOfPage, String? name, SchemaThing? object, dynamic owner, dynamic participant, SchemaAction? potentialAction, dynamic provider, dynamic recipient, SchemaThing? result, String? sameAs, String? startTime, dynamic subjectOf, dynamic target, String? url, SchemaComment? resultComment})
- Create a new instance of SchemaReplyAction
Properties
- about ↔ SchemaThing?
-
The subject matter of an object.
getter/setter pairinherited
- actionProcess ↔ SchemaHowTo?
-
Description of the process by which the action was performed.
getter/setter pairinherited
- actionStatus ↔ SchemaActionStatusType?
-
Indicates the current disposition of the Action.
getter/setter pairinherited
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- agent ↔ dynamic
-
The direct performer or driver of the action (animate or inanimate). E.g.
John wrote a book.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- endTime ↔ String?
-
The endTime of something. For a reserved event or service (e.g.
FoodEstablishmentReservation), the time that it is expected to end. For
actions that span a period of time, when the action was performed. E.g.
John wrote a book from January to December. For media, including audio
and video, it's the time offset of the end of a clip within a larger
file.\n\nNote that Event uses startDate/endDate instead of
startTime/endTime, even when describing dates with times. This situation
may be clarified in future revisions.
getter/setter pairinherited
- error ↔ SchemaThing?
-
For failed actions, more information on the cause of the failure.
Consider using the Error type.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - inLanguage ↔ dynamic
-
//tools.ietf.org/html/bcp47). See also
SchemaavailableLanguage.getter/setter pairinherited - instrument ↔ SchemaThing?
-
The object that helped the agent perform the action. E.g. John wrote a
book with a pen.
getter/setter pairinherited
- language ↔ SchemaLanguage?
-
A sub property of instrument. The language used on this action.
getter/setter pairinherited
- location ↔ dynamic
-
The location of, for example, where an event is happening, where an
organization is located, or where an action takes place.
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- object ↔ SchemaThing?
-
The object upon which the action is carried out, whose state is kept
intact or changed. Also known as the semantic roles patient, affected or
undergoer (which change their state) or theme (which doesn't). E.g. John
read a book.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- participant ↔ dynamic
-
Other co-agents that participated in the action indirectly. E.g. John
wrote a book with Steve.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- provider ↔ dynamic
-
The service provider, service operator, or service performer; the goods
producer. Another party (a seller) may offer those services or goods on
behalf of the provider. A provider may also serve as the seller.
getter/setter pairinherited
- recipient ↔ dynamic
-
A sub property of participant. The participant who is at the receiving
end of the action.
getter/setter pairinherited
- result ↔ SchemaThing?
-
The result produced in the action. E.g. John wrote a book.
getter/setter pairinherited
- resultComment ↔ SchemaComment?
-
A sub property of result. The Comment created or sent as a result of this
action.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- startTime ↔ String?
-
The startTime of something. For a reserved event or service (e.g.
FoodEstablishmentReservation), the time that it is expected to start. For
actions that span a period of time, when the action was performed. E.g.
John wrote a book from January to December. For media, including audio
and video, it's the time offset of the start of a clip within a larger
file.\n\nNote that Event uses startDate/endDate instead of
startTime/endTime, even when describing dates with times. This situation
may be clarified in future revisions.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- target ↔ dynamic
-
Indicates a target EntryPoint, or url, for an Action.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaReplyAction to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited