SchemaStatisticalVariable class
the population type is SchemaPerson; the measuredProperty
Schemaheight; the SchemastatType Schemamedian; the Schemagender
SchemaFemale. It is important to note that there are many kinds of
scientific quantitative observation which are not fully, perfectly or
unambiguously described following this pattern, or with solely Schema.org
terminology. The approach taken here is designed to allow partial,
incremental or minimal description of SchemaStatisticalVariables, and
the use of detailed sets of entity and property IDs from external
repositories. The SchemameasurementMethod, SchemaunitCode and
SchemaunitText properties can also be used to clarify the specific
nature and notation of an observed measurement.
See https://schema.org/StatisticalVariable
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaConstraintNode
- SchemaStatisticalVariable
Constructors
- SchemaStatisticalVariable({String? additionalType, String? alternateName, dynamic constraintProperty, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, int? numConstraints, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, SchemaProperty? measuredProperty, SchemaStatisticalVariable? measurementDenominator, dynamic measurementMethod, SchemaEnumeration? measurementQualifier, dynamic measurementTechnique, SchemaClass? populationType, dynamic statType})
- Create a new instance of SchemaStatisticalVariable
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- constraintProperty ↔ dynamic
-
Indicates a property used as a constraint. For example, in the definition
of a SchemaStatisticalVariable. The value is a property, either from
within Schema.org or from other compatible (e.g. RDF) systems such as
DataCommons.org or Wikidata.org.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- measuredProperty ↔ SchemaProperty?
-
//www.gs1.org/voc/?show=properties).
getter/setter pair
- measurementDenominator ↔ SchemaStatisticalVariable?
-
Identifies the denominator variable when an observation represents a
ratio or percentage.
getter/setter pair
- measurementMethod ↔ dynamic
-
A subproperty of
SchemameasurementTechniquethat can be used for specifying specific methods, in particular via SchemaMeasurementMethodEnum.getter/setter pair - measurementQualifier ↔ SchemaEnumeration?
-
Provides additional qualification to an observation. For example, a GDP
observation measures the Nominal value.
getter/setter pair
- measurementTechnique ↔ dynamic
-
"mass spectrometry" or "nmr spectroscopy" or "colorimetry" or
"immunofluorescence". If the
SchemavariableMeasuredis "depression rating", theSchemameasurementTechniquecould be "Zung Scale" or "HAM-D" or "Beck Depression Inventory".getter/setter pair - name ↔ String?
-
The name of the item.
getter/setter pairinherited
- numConstraints ↔ int?
-
Indicates the number of constraints property values defined for a
particular SchemaConstraintNode such as SchemaStatisticalVariable.
This helps applications understand if they have access to a sufficiently
complete description of a SchemaStatisticalVariable or other construct
that is defined using properties on template-style nodes.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- populationType ↔ SchemaClass?
-
Indicates the populationType common to all members of a
SchemaStatisticalPopulation or all cases within the scope of a
SchemaStatisticalVariable.
getter/setter pair
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- statType ↔ dynamic
-
Indicates the kind of statistic represented by a
SchemaStatisticalVariable, e.g. mean, count etc. The value of statType
is a property, either from within Schema.org (e.g.
Schemamedian,SchemamarginOfError,SchemamaxValue,SchemaminValue) or from other compatible (e.g. RDF) systems such as DataCommons.org or Wikidata.org.getter/setter pair - subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaStatisticalVariable to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited