SchemaTaxon class
A set of organisms asserted to represent a natural cohesive biological unit. See https://schema.org/Taxon
- Inheritance
-
- Object
- SchemaThing
- SchemaTaxon
Constructors
- SchemaTaxon({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic childTaxon, SchemaDefinedTerm? hasDefinedTerm, dynamic parentTaxon, dynamic taxonRank})
- Create a new instance of SchemaTaxon
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- childTaxon ↔ dynamic
-
Closest child taxa of the taxon in question.
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- hasDefinedTerm ↔ SchemaDefinedTerm?
-
A Defined Term contained in this term set.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- parentTaxon ↔ dynamic
-
Closest parent taxon of the taxon in question.
getter/setter pair
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- taxonRank ↔ dynamic
-
The taxonomic rank of this taxon given preferably as a URI from a
controlled vocabulary – typically the ranks from TDWG TaxonRank ontology
or equivalent Wikidata URIs.
getter/setter pair
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaTaxon to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited