SchemaTrainReservation class
This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use SchemaOffer. See https://schema.org/TrainReservation
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaReservation
- SchemaTrainReservation
Constructors
- SchemaTrainReservation({String? additionalType, String? alternateName, dynamic bookingAgent, String? bookingTime, dynamic broker, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? modifiedTime, String? name, dynamic owner, SchemaAction? potentialAction, String? priceCurrency, SchemaProgramMembership? programMembershipUsed, dynamic provider, SchemaThing? reservationFor, String? reservationId, SchemaReservationStatusType? reservationStatus, SchemaTicket? reservedTicket, String? sameAs, dynamic subjectOf, dynamic totalPrice, dynamic underName, String? url})
- Create a new instance of SchemaTrainReservation
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- bookingAgent ↔ dynamic
-
'bookingAgent' is an out-dated term indicating a 'broker' that serves as
a booking agent.
getter/setter pairinherited
- bookingTime ↔ String?
-
The date and time the reservation was booked.
getter/setter pairinherited
- broker ↔ dynamic
-
An entity that arranges for an exchange between a buyer and a seller. In
most cases a broker never acquires or releases ownership of a product or
service involved in an exchange. If it is not clear whether an entity is
a broker, seller, or buyer, the latter two terms are preferred.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- modifiedTime ↔ String?
-
The date and time the reservation was modified.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- priceCurrency ↔ String?
-
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other
currency types, e.g. "Ithaca HOUR".
getter/setter pairinherited
- programMembershipUsed ↔ SchemaProgramMembership?
-
Any membership in a frequent flyer, hotel loyalty program, etc. being
applied to the reservation.
getter/setter pairinherited
- provider ↔ dynamic
-
The service provider, service operator, or service performer; the goods
producer. Another party (a seller) may offer those services or goods on
behalf of the provider. A provider may also serve as the seller.
getter/setter pairinherited
- reservationFor ↔ SchemaThing?
-
The thing -- flight, event, restaurant, etc. being reserved.
getter/setter pairinherited
- reservationId ↔ String?
-
A unique identifier for the reservation.
getter/setter pairinherited
- reservationStatus ↔ SchemaReservationStatusType?
-
The current status of the reservation.
getter/setter pairinherited
- reservedTicket ↔ SchemaTicket?
-
A ticket associated with the reservation.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- totalPrice ↔ dynamic
-
\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT
NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use
'.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal
point. Avoid using these symbols as a readability separator.
getter/setter pairinherited
- underName ↔ dynamic
-
The person or organization the reservation or ticket is for.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaTrainReservation to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited