SchemaUnitPriceSpecification class

The price asked for a given offer by the respective organization or person. See https://schema.org/UnitPriceSpecification

Inheritance

Constructors

SchemaUnitPriceSpecification({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, SchemaQuantitativeValue? eligibleQuantity, SchemaPriceSpecification? eligibleTransactionVolume, dynamic identifier, dynamic image, dynamic mainEntityOfPage, num? maxPrice, dynamic membershipPointsEarned, num? minPrice, String? name, dynamic owner, SchemaAction? potentialAction, dynamic price, String? priceCurrency, String? sameAs, dynamic subjectOf, String? url, SchemaMemberProgramTier? validForMemberTier, String? validFrom, String? validThrough, bool? valueAddedTaxIncluded, dynamic billingDuration, num? billingIncrement, num? billingStart, SchemaPriceComponentTypeEnumeration? priceComponentType, dynamic priceType, SchemaQuantitativeValue? referenceQuantity, String? unitCode, String? unitText})
Create a new instance of SchemaUnitPriceSpecification

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
billingDuration ↔ dynamic
Specifies for how long this price (or price component) will be billed. Can be used, for example, to model the contractual duration of a subscription or payment plan. Type can be either a Duration or a Number (in which case the unit of measurement, for example month, is specified by the unitCode property).
getter/setter pair
billingIncrement num?
This property specifies the minimal quantity and rounding increment that will be the basis for the billing. The unit of measurement is specified by the unitCode property.
getter/setter pair
billingStart num?
Specifies after how much time this price (or price component) becomes valid and billing starts. Can be used, for example, to model a price increase after the first year of a subscription. The unit of measurement is specified by the unitCode property.
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
eligibleQuantity SchemaQuantitativeValue?
The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
getter/setter pairinherited
eligibleTransactionVolume SchemaPriceSpecification?
The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
maxPrice num?
The highest price if the price is a range.
getter/setter pairinherited
membershipPointsEarned ↔ dynamic
The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)
getter/setter pairinherited
minPrice num?
The lowest price if the price is a range.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
price ↔ dynamic
//www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and Microdata syntax allow the use of a "content=" attribute for publishing simple machine-readable values alongside more human-friendly formatting.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.
getter/setter pairinherited
priceComponentType SchemaPriceComponentTypeEnumeration?
Identifies a price component (for example, a line item on an invoice), part of the total price for an offer.
getter/setter pair
priceCurrency String?
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".
getter/setter pairinherited
priceType ↔ dynamic
Defines the type of a price specified for an offered product, for example a list price, a (temporary) sale price or a manufacturer suggested retail price. If multiple prices are specified for an offer the SchemapriceType property can be used to identify the type of each such specified price. The value of priceType can be specified as a value from enumeration PriceTypeEnumeration or, a UN/EDIFACT 5387 code, or as a free form text string for price types that are not already predefined in PriceTypeEnumeration.
getter/setter pair
referenceQuantity SchemaQuantitativeValue?
The reference quantity for which a certain price applies, e.g. 1 EUR per 4 kWh of electricity. This property is a replacement for unitOfMeasurement for the advanced cases where the price does not relate to a standard unit.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
unitCode String?
The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.
getter/setter pair
unitText String?
A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for unitCode.
getter/setter pair
url String?
URL of the item.
getter/setter pairinherited
validForMemberTier SchemaMemberProgramTier?
The membership program tier(s) an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.
getter/setter pairinherited
validFrom String?
The date when the item becomes valid.
getter/setter pairinherited
validThrough String?
The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.
getter/setter pairinherited
valueAddedTaxIncluded bool?
Specifies whether the applicable value-added tax (VAT) is included in the price specification or not.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaUnitPriceSpecification to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited