SchemaWorkBasedProgram class

A program with both an educational and employment component. Typically based at a workplace and structured around work-based learning, with the aim of instilling competencies related to an occupation. WorkBasedProgram is used to distinguish programs such as apprenticeships from school, college or other classroom based educational programs. See https://schema.org/WorkBasedProgram

Inheritance

Constructors

SchemaWorkBasedProgram({String? additionalType, String? alternateName, String? applicationDeadline, String? applicationStartDate, SchemaDayOfWeek? dayOfWeek, dynamic description, String? disambiguatingDescription, dynamic educationalCredentialAwarded, String? educationalProgramMode, String? endDate, dynamic financialAidEligible, SchemaCourse? hasCourse, dynamic identifier, dynamic image, dynamic mainEntityOfPage, int? maximumEnrollment, String? name, dynamic numberOfCredits, dynamic occupationalCategory, dynamic occupationalCredentialAwarded, dynamic offers, dynamic owner, SchemaAction? potentialAction, dynamic programPrerequisites, dynamic programType, dynamic provider, SchemaMonetaryAmountDistribution? salaryUponCompletion, String? sameAs, String? startDate, dynamic subjectOf, SchemaDuration? termDuration, num? termsPerYear, String? timeOfDay, SchemaDuration? timeToComplete, SchemaMonetaryAmountDistribution? trainingSalary, dynamic typicalCreditsPerTerm, String? url})
Create a new instance of SchemaWorkBasedProgram

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
applicationDeadline String?
The date on which the program stops collecting applications for the next enrollment cycle. Flexible application deadlines (for example, a program with rolling admissions) can be described in a textual string, rather than as a DateTime.
getter/setter pairinherited
applicationStartDate String?
The date at which the program begins collecting applications for the next enrollment cycle.
getter/setter pairinherited
dayOfWeek SchemaDayOfWeek?
The day of the week for which these opening hours are valid.
getter/setter pairinherited
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
educationalCredentialAwarded ↔ dynamic
A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.
getter/setter pairinherited
educationalProgramMode String?
//ceds.ed.gov/element/001311#Asynchronous ).
getter/setter pairinherited
endDate String?
//en.wikipedia.org/wiki/ISO_8601)).
getter/setter pairinherited
financialAidEligible ↔ dynamic
A financial aid type or program which students may use to pay for tuition or fees associated with the program.
getter/setter pairinherited
hasCourse SchemaCourse?
A course or class that is one of the learning opportunities that constitute an educational / occupational program. No information is implied about whether the course is mandatory or optional; no guarantee is implied about whether the course will be available to everyone on the program.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
maximumEnrollment int?
The maximum number of students who may be enrolled in the program.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
numberOfCredits ↔ dynamic
The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.
getter/setter pairinherited
occupationalCategory ↔ dynamic
for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.
getter/setter pairinherited
occupationalCredentialAwarded ↔ dynamic
A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.
getter/setter pairinherited
offers ↔ dynamic
An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use SchemabusinessFunction to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
programPrerequisites ↔ dynamic
Prerequisites for enrolling in the program.
getter/setter pairinherited
programType ↔ dynamic
The type of educational or occupational program. For example, classroom, internship, alternance, etc.
getter/setter pairinherited
provider ↔ dynamic
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salaryUponCompletion SchemaMonetaryAmountDistribution?
The expected salary upon completing the training.
getter/setter pairinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
startDate String?
//en.wikipedia.org/wiki/ISO_8601)).
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
termDuration SchemaDuration?
The amount of time in a term as defined by the institution. A term is a length of time where students take one or more classes. Semesters and quarters are common units for term.
getter/setter pairinherited
termsPerYear num?
The number of times terms of study are offered per year. Semesters and quarters are common units for term. For example, if the student can only take 2 semesters for the program in one year, then termsPerYear should be 2.
getter/setter pairinherited
timeOfDay String?
The time of day the program normally runs. For example, "evenings".
getter/setter pairinherited
timeToComplete SchemaDuration?
The expected length of time to complete the program if attending full-time.
getter/setter pairinherited
trainingSalary SchemaMonetaryAmountDistribution?
The estimated salary earned while in the program.
getter/setter pairinherited
typicalCreditsPerTerm ↔ dynamic
The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.
getter/setter pairinherited
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaWorkBasedProgram to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited