claimInterpreter property
dynamic
claimInterpreter
getter/setter pair
For a SchemaClaim interpreted from SchemaMediaObject content, the
SchemainterpretedAsClaim property can be used to indicate a claim
contained, implied or refined from the content of a SchemaMediaObject.
Supported types: SchemaOrganization, SchemaPerson
Implementation
dynamic claimInterpreter;