SchemaEnergy class
Properties that take Energy as values are of the form '<Number> <Energy unit of measure>'. See https://schema.org/Energy
- Inheritance
-
- Object
- SchemaQuantity
- SchemaEnergy
Constructors
- SchemaEnergy()
- Create a new instance of SchemaEnergy
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaEnergy to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited