hasParticipationOffer property
An offer to participate in the event, for example, Call for Proposals, Call for Speakers, or Call for Performers.
Implementation
SchemaOffer? hasParticipationOffer;
An offer to participate in the event, for example, Call for Proposals, Call for Speakers, or Call for Performers.
SchemaOffer? hasParticipationOffer;