SchemaGeoCoordinates class
The geographic coordinates of a place or event. See https://schema.org/GeoCoordinates
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaStructuredValue
- SchemaGeoCoordinates
Constructors
- SchemaGeoCoordinates({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic address, dynamic addressCountry, dynamic elevation, dynamic latitude, dynamic longitude, String? postalCode})
- Create a new instance of SchemaGeoCoordinates
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- address ↔ dynamic
-
Physical address of the item.
getter/setter pair
- addressCountry ↔ dynamic
-
//en.wikipedia.org/wiki/ISO_3166-1_alpha-3) country code such as "SGP" or
a full country name such as "Singapore" can also be used.
getter/setter pair
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- elevation ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)). Values may be of the
form 'NUMBER UNIT_OF_MEASUREMENT' (e.g., '1,000 m', '3,200 ft') while
numbers alone should be assumed to be a value in meters.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - latitude ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)).
getter/setter pair
- longitude ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)).
getter/setter pair
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- postalCode ↔ String?
-
The postal code. For example, 94043.
getter/setter pair
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaGeoCoordinates to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited