SchemaMusicGroup class
A musical group, such as a band, an orchestra, or a choir. Can also be a solo musician. See https://schema.org/MusicGroup
- Inheritance
-
- Object
- SchemaThing
- SchemaOrganization
- SchemaPerformingGroup
- SchemaMusicGroup
Constructors
- SchemaMusicGroup({dynamic acceptedPaymentMethod, dynamic actionableFeedbackPolicy, String? additionalType, dynamic address, SchemaInteractionCounter? agentInteractionStatistic, SchemaAggregateRating? aggregateRating, String? alternateName, SchemaPerson? alumni, dynamic areaServed, String? award, String? awards, dynamic brand, SchemaCertification? companyRegistration, SchemaContactPoint? contactPoint, SchemaContactPoint? contactPoints, dynamic correctionsPolicy, SchemaOrganization? department, dynamic description, String? disambiguatingDescription, String? dissolutionDate, dynamic diversityPolicy, dynamic diversityStaffingReport, String? duns, String? email, SchemaPerson? employee, SchemaPerson? employees, dynamic ethicsPolicy, SchemaEvent? event, SchemaEvent? events, String? faxNumber, dynamic founder, SchemaPerson? founders, String? foundingDate, SchemaPlace? foundingLocation, dynamic funder, SchemaGrant? funding, String? globalLocationNumber, SchemaCertification? hasCertification, SchemaCredential? hasCredential, String? hasGS1DigitalLink, SchemaMemberProgram? hasMemberProgram, SchemaMerchantReturnPolicy? hasMerchantReturnPolicy, SchemaOfferCatalog? hasOfferCatalog, SchemaPlace? hasPOS, SchemaShippingService? hasShippingService, dynamic identifier, dynamic image, SchemaInteractionCounter? interactionStatistic, String? isicV4, String? iso6523Code, dynamic keywords, dynamic knowsAbout, dynamic knowsLanguage, SchemaPostalAddress? legalAddress, String? legalName, SchemaPerson? legalRepresentative, String? leiCode, dynamic location, dynamic logo, dynamic mainEntityOfPage, SchemaOffer? makesOffer, dynamic member, dynamic memberOf, dynamic members, String? naics, String? name, SchemaNonprofitType? nonprofitStatus, SchemaQuantitativeValue? numberOfEmployees, dynamic owner, dynamic ownershipFundingInfo, SchemaThing? owns, SchemaOrganization? parentOrganization, SchemaAction? potentialAction, dynamic publishingPrinciples, SchemaReview? review, SchemaReview? reviews, String? sameAs, SchemaDemand? seeks, dynamic serviceArea, dynamic skills, String? slogan, dynamic sponsor, SchemaOrganization? subOrganization, dynamic subjectOf, String? taxID, String? telephone, dynamic unnamedSourcesPolicy, String? url, String? vatID, SchemaMusicAlbum? album, SchemaMusicAlbum? albums, dynamic genre, SchemaPerson? musicGroupMember, dynamic track, SchemaMusicRecording? tracks})
- Create a new instance of SchemaMusicGroup
Properties
- acceptedPaymentMethod ↔ dynamic
-
The payment method(s) that are accepted in general by an organization, or
for some specific demand or offer.
getter/setter pairinherited
- actionableFeedbackPolicy ↔ dynamic
-
For a SchemaNewsMediaOrganization or other news-related
SchemaOrganization, a statement about public engagement activities (for
news media, the newsroom’s), including involving the public - digitally
or otherwise -- in coverage decisions, reporting and activities after
publication.
getter/setter pairinherited
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- address ↔ dynamic
-
Physical address of the item.
getter/setter pairinherited
- agentInteractionStatistic ↔ SchemaInteractionCounter?
-
The number of completed interactions for this entity, in a particular
role (the 'agent'), in a particular action (indicated in the statistic),
and in a particular context (i.e. interactionService).
getter/setter pairinherited
- aggregateRating ↔ SchemaAggregateRating?
-
The overall rating, based on a collection of reviews or ratings, of the
item.
getter/setter pairinherited
- album ↔ SchemaMusicAlbum?
-
A music album.
getter/setter pair
- albums ↔ SchemaMusicAlbum?
-
A collection of music albums.
getter/setter pair
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- alumni ↔ SchemaPerson?
-
Alumni of an organization.
getter/setter pairinherited
- areaServed ↔ dynamic
-
The geographic area where a service or offered item is provided.
getter/setter pairinherited
- award ↔ String?
-
An award won by or for this item.
getter/setter pairinherited
- awards ↔ String?
-
Awards won by or for this item.
getter/setter pairinherited
- brand ↔ dynamic
-
The brand(s) associated with a product or service, or the brand(s)
maintained by an organization or business person.
getter/setter pairinherited
- companyRegistration ↔ SchemaCertification?
-
The official registration information of a business including the
organization that issued it such as Company House or Chamber of Commerce
in form of a Certification.
getter/setter pairinherited
- contactPoint ↔ SchemaContactPoint?
-
A contact point for a person or organization.
getter/setter pairinherited
- contactPoints ↔ SchemaContactPoint?
-
A contact point for a person or organization.
getter/setter pairinherited
- correctionsPolicy ↔ dynamic
-
For an SchemaOrganization (e.g. SchemaNewsMediaOrganization), a
statement describing (in news media, the newsroom’s) disclosure and
correction policy for errors.
getter/setter pairinherited
- department ↔ SchemaOrganization?
-
a store with a pharmacy, or a bakery with a cafe.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- dissolutionDate ↔ String?
-
The date that this organization was dissolved.
getter/setter pairinherited
- diversityPolicy ↔ dynamic
-
Statement on diversity policy by an SchemaOrganization e.g. a
SchemaNewsMediaOrganization. For a SchemaNewsMediaOrganization, a
statement describing the newsroom’s diversity policy on both staffing and
sources, typically providing staffing data.
getter/setter pairinherited
- diversityStaffingReport ↔ dynamic
-
For an SchemaOrganization (often but not necessarily a
SchemaNewsMediaOrganization), a report on staffing diversity issues. In
a news context this might be for example ASNE or RTDNA (US) reports, or
self-reported.
getter/setter pairinherited
- duns ↔ String?
-
The Dun & Bradstreet DUNS number for identifying an organization or
business person.
getter/setter pairinherited
- email ↔ String?
-
Email address.
getter/setter pairinherited
- employee ↔ SchemaPerson?
-
Someone working for this organization.
getter/setter pairinherited
- employees ↔ SchemaPerson?
-
People working for this organization.
getter/setter pairinherited
- ethicsPolicy ↔ dynamic
-
Statement about ethics policy, e.g. of a SchemaNewsMediaOrganization
regarding journalistic and publishing practices, or of a
SchemaRestaurant, a page describing food source policies. In the case
of a SchemaNewsMediaOrganization, an ethicsPolicy is typically a
statement describing the personal, organizational, and corporate
standards of behavior expected by the organization.
getter/setter pairinherited
- event ↔ SchemaEvent?
-
Upcoming or past event associated with this place, organization, or
action.
getter/setter pairinherited
- events ↔ SchemaEvent?
-
Upcoming or past events associated with this place or organization.
getter/setter pairinherited
- faxNumber ↔ String?
-
The fax number.
getter/setter pairinherited
- founder ↔ dynamic
-
A person or organization who founded this organization.
getter/setter pairinherited
- founders ↔ SchemaPerson?
-
A person who founded this organization.
getter/setter pairinherited
- foundingDate ↔ String?
-
The date that this organization was founded.
getter/setter pairinherited
- foundingLocation ↔ SchemaPlace?
-
The place where the Organization was founded.
getter/setter pairinherited
- funder ↔ dynamic
-
A person or organization that supports (sponsors) something through some
kind of financial contribution.
getter/setter pairinherited
- funding ↔ SchemaGrant?
-
A SchemaGrant that directly or indirectly provide funding or
sponsorship for this item. See also
SchemaownershipFundingInfo.getter/setter pairinherited - genre ↔ dynamic
-
Genre of the creative work, broadcast channel or group.
getter/setter pair
- globalLocationNumber ↔ String?
-
//www.gs1.org/gln) (GLN, sometimes also referred to as International
Location Number or ILN) of the respective organization, person, or place.
The GLN is a 13-digit number used to identify parties and physical
locations.
getter/setter pairinherited
- hasCertification ↔ SchemaCertification?
-
Certification information about a product, organization, service, place,
or person.
getter/setter pairinherited
- hasCredential ↔ SchemaCredential?
-
A credential awarded to the Person or Organization.
getter/setter pairinherited
- hasGS1DigitalLink ↔ String?
-
- A Digital Link that contains a serial number (AI
21) should only be present on instances of [SchemaIndividualProduct]- A Digital Link that contains a lot number (AI
10) should be annotated as [SchemaSomeProducts] if only products from that lot are sold, or [SchemaIndividualProduct] if there is only a specific product.- A Digital Link that contains a global model number (AI
8013) should be attached to a [SchemaProduct] or a [SchemaProductModel].getter/setter pairinherited - A Digital Link that contains a serial number (AI
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMemberProgram ↔ SchemaMemberProgram?
-
MemberProgram offered by an Organization, for example an eCommerce
merchant or an airline.
getter/setter pairinherited
- hasMerchantReturnPolicy ↔ SchemaMerchantReturnPolicy?
-
Specifies a MerchantReturnPolicy that may be applicable.
getter/setter pairinherited
- hasOfferCatalog ↔ SchemaOfferCatalog?
-
Indicates an OfferCatalog listing for this Organization, Person, or
Service.
getter/setter pairinherited
- hasPOS ↔ SchemaPlace?
-
Points-of-Sales operated by the organization or person.
getter/setter pairinherited
- hasShippingService ↔ SchemaShippingService?
-
Specification of a shipping service offered by the organization.
getter/setter pairinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - interactionStatistic ↔ SchemaInteractionCounter?
-
The number of interactions for the CreativeWork using the WebSite or
SoftwareApplication. The most specific child type of InteractionCounter
should be used.
getter/setter pairinherited
- isicV4 ↔ String?
-
The International Standard of Industrial Classification of All Economic
Activities (ISIC), Revision 4 code for a particular organization,
business person, or place.
getter/setter pairinherited
- iso6523Code ↔ String?
-
//schema.org/taxID), as ISO identifiers are less ambiguous.
getter/setter pairinherited
- keywords ↔ dynamic
-
Keywords or tags used to describe some item. Multiple textual entries in
a keywords list are typically delimited by commas, or by repeating the
property.
getter/setter pairinherited
- knowsAbout ↔ dynamic
-
Of a SchemaPerson, and less typically of an SchemaOrganization, to
indicate a topic that is known about - suggesting possible expertise but
not implying it. We do not distinguish skill levels here, or relate this
to educational content, events, objectives or SchemaJobPosting
descriptions.
getter/setter pairinherited
- knowsLanguage ↔ dynamic
-
//tools.ietf.org/html/bcp47).
getter/setter pairinherited
- legalAddress ↔ SchemaPostalAddress?
-
The legal address of an organization which acts as the officially
registered address used for legal and tax purposes. The legal address can
be different from the place of operations of a business and other
addresses can be part of an organization.
getter/setter pairinherited
- legalName ↔ String?
-
The official name of the organization, e.g. the registered company name.
getter/setter pairinherited
- legalRepresentative ↔ SchemaPerson?
-
One or multiple persons who represent this organization legally such as
CEO or sole administrator.
getter/setter pairinherited
- leiCode ↔ String?
-
An organization identifier that uniquely identifies a legal entity as
defined in ISO 17442.
getter/setter pairinherited
- location ↔ dynamic
-
The location of, for example, where an event is happening, where an
organization is located, or where an action takes place.
getter/setter pairinherited
- logo ↔ dynamic
-
An associated logo.
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- makesOffer ↔ SchemaOffer?
-
A pointer to products or services offered by the organization or person.
getter/setter pairinherited
- member ↔ dynamic
-
A member of an Organization or a ProgramMembership. Organizations can be
members of organizations; ProgramMembership is typically for individuals.
getter/setter pairinherited
- memberOf ↔ dynamic
-
An Organization (or ProgramMembership) to which this Person or
Organization belongs.
getter/setter pairinherited
- members ↔ dynamic
-
A member of this organization.
getter/setter pairinherited
- musicGroupMember ↔ SchemaPerson?
-
A member of a music group—for example, John, Paul, George, or
Ringo.
getter/setter pair
- naics ↔ String?
-
The North American Industry Classification System (NAICS) code for a
particular organization or business person.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- nonprofitStatus ↔ SchemaNonprofitType?
-
nonprofitStatus indicates the legal status of a non-profit organization
in its primary place of business.
getter/setter pairinherited
- numberOfEmployees ↔ SchemaQuantitativeValue?
-
The number of employees in an organization, e.g. business.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- ownershipFundingInfo ↔ dynamic
-
For an SchemaOrganization (often but not necessarily a
SchemaNewsMediaOrganization), a description of organizational ownership
structure; funding and grants. In a news/media setting, this is with
particular reference to editorial independence. Note that the
Schemafunderis also available and can be used to make basic funder information machine-readable.getter/setter pairinherited - owns ↔ SchemaThing?
-
Things owned by the organization or person.
getter/setter pairinherited
- parentOrganization ↔ SchemaOrganization?
-
The larger organization that this organization is a
SchemasubOrganizationof, if any.getter/setter pairinherited - potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- publishingPrinciples ↔ dynamic
-
The publishingPrinciples property indicates (typically via
SchemaURL) a document describing the editorial principles of an SchemaOrganization (or individual, e.g. a SchemaPerson writing a blog) that relate to their activities as a publisher, e.g. ethics or diversity policies. When applied to a SchemaCreativeWork (e.g. SchemaNewsArticle) the principles are those of the party primarily responsible for the creation of the SchemaCreativeWork.getter/setter pairinherited - review ↔ SchemaReview?
-
A review of the item.
getter/setter pairinherited
- reviews ↔ SchemaReview?
-
Review of the item.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- seeks ↔ SchemaDemand?
-
A pointer to products or services sought by the organization or person
(demand).
getter/setter pairinherited
- serviceArea ↔ dynamic
-
The geographic area where the service is provided.
getter/setter pairinherited
- skills ↔ dynamic
-
A statement of knowledge, skill, ability, task or any other assertion
expressing a competency that is either claimed by a person, an
organization or desired or required to fulfill a role or to work in an
occupation.
getter/setter pairinherited
- slogan ↔ String?
-
A slogan or motto associated with the item.
getter/setter pairinherited
- sponsor ↔ dynamic
-
A person or organization that supports a thing through a pledge, promise,
or financial contribution. E.g. a sponsor of a Medical Study or a
corporate sponsor of an event.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- subOrganization ↔ SchemaOrganization?
-
the more specific 'department' property.
getter/setter pairinherited
- taxID ↔ String?
-
The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US
or the CIF/NIF in Spain.
getter/setter pairinherited
- telephone ↔ String?
-
The telephone number.
getter/setter pairinherited
- track ↔ dynamic
-
A music recording (track)—usually a single song. If an ItemList is
given, the list should contain items of type MusicRecording.
getter/setter pair
- tracks ↔ SchemaMusicRecording?
-
A music recording (track)—usually a single song.
getter/setter pair
- unnamedSourcesPolicy ↔ dynamic
-
For an SchemaOrganization (typically a SchemaNewsMediaOrganization),
a statement about policy on use of unnamed sources and the decision
process required.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
- vatID ↔ String?
-
The value-added Tax ID of the organization or person with national prefix
(for example IT123456789). Can also be described as
Schemaiso6523Codewith proper prefix.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaMusicGroup to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited