SchemaOccupation class
A profession, may involve prolonged training and/or a formal qualification. See https://schema.org/Occupation
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaOccupation
Constructors
- SchemaOccupation({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic educationRequirements, dynamic estimatedSalary, dynamic experienceRequirements, SchemaAdministrativeArea? occupationLocation, dynamic occupationalCategory, dynamic qualifications, String? responsibilities, dynamic skills})
- Create a new instance of SchemaOccupation
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- educationRequirements ↔ dynamic
-
Educational background needed for the position or Occupation.
getter/setter pair
- estimatedSalary ↔ dynamic
-
An estimated salary for a job posting or occupation, based on a variety
of variables including, but not limited to industry, job title, and
location. Estimated salaries are often computed by outside organizations
rather than the hiring organization, who may not have committed to the
estimated value.
getter/setter pair
- experienceRequirements ↔ dynamic
-
Description of skills and experience needed for the position or
Occupation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- occupationalCategory ↔ dynamic
-
for historical reasons, any textual label and formal code provided as a
literal may be assumed to be from O*NET-SOC.
getter/setter pair
- occupationLocation ↔ SchemaAdministrativeArea?
-
The region/country for which this occupational description is
appropriate. Note that educational requirements and qualifications can
vary between jurisdictions.
getter/setter pair
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- qualifications ↔ dynamic
-
Specific qualifications required for this role or Occupation.
getter/setter pair
- responsibilities ↔ String?
-
Responsibilities associated with this role or Occupation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- skills ↔ dynamic
-
A statement of knowledge, skill, ability, task or any other assertion
expressing a competency that is either claimed by a person, an
organization or desired or required to fulfill a role or to work in an
occupation.
getter/setter pair
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaOccupation to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited