SchemaParcelDelivery class

The delivery of a parcel either via the postal service or a commercial service. See https://schema.org/ParcelDelivery

Inheritance

Constructors

SchemaParcelDelivery({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, SchemaOrganization? carrier, SchemaPostalAddress? deliveryAddress, SchemaDeliveryEvent? deliveryStatus, String? expectedArrivalFrom, String? expectedArrivalUntil, SchemaDeliveryMethod? hasDeliveryMethod, SchemaProduct? itemShipped, SchemaPostalAddress? originAddress, SchemaOrder? partOfOrder, dynamic provider, String? trackingNumber, String? trackingUrl})
Create a new instance of SchemaParcelDelivery

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
carrier SchemaOrganization?
'carrier' is an out-dated term indicating the 'provider' for parcel delivery and flights.
getter/setter pair
deliveryAddress SchemaPostalAddress?
Destination address.
getter/setter pair
deliveryStatus SchemaDeliveryEvent?
New entry added as the package passes through each leg of its journey (from shipment to final delivery).
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
expectedArrivalFrom String?
The earliest date the package may arrive.
getter/setter pair
expectedArrivalUntil String?
The latest date the package may arrive.
getter/setter pair
hasDeliveryMethod SchemaDeliveryMethod?
Method used for delivery or shipping.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
itemShipped SchemaProduct?
Item(s) being shipped.
getter/setter pair
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
originAddress SchemaPostalAddress?
Shipper's address.
getter/setter pair
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
partOfOrder SchemaOrder?
The overall order the items in this delivery were included in.
getter/setter pair
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
provider ↔ dynamic
The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
trackingNumber String?
Shipper tracking number.
getter/setter pair
trackingUrl String?
Tracking url for the parcel delivery.
getter/setter pair
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaParcelDelivery to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited