SchemaPaymentCard class
A payment method using a credit, debit, store or other card to associate the payment with an account. See https://schema.org/PaymentCard
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaService
- SchemaFinancialProduct
- SchemaPaymentCard
- Implemented types
- Implementers
Constructors
- SchemaPaymentCard({String? additionalType, SchemaAggregateRating? aggregateRating, String? alternateName, dynamic annualPercentageRate, dynamic areaServed, SchemaAudience? audience, SchemaServiceChannel? availableChannel, String? award, dynamic brand, dynamic broker, dynamic category, dynamic description, String? disambiguatingDescription, String? feesAndCommissionsSpecification, SchemaCertification? hasCertification, SchemaOfferCatalog? hasOfferCatalog, SchemaOpeningHoursSpecification? hoursAvailable, dynamic identifier, dynamic image, dynamic interestRate, dynamic isRelatedTo, dynamic isSimilarTo, dynamic logo, dynamic mainEntityOfPage, String? name, dynamic offers, dynamic owner, SchemaAction? potentialAction, SchemaThing? produces, dynamic provider, String? providerMobility, SchemaReview? review, String? sameAs, dynamic serviceArea, SchemaAudience? serviceAudience, SchemaThing? serviceOutput, dynamic serviceType, String? slogan, dynamic subjectOf, String? termsOfService, String? url, dynamic cashBack, bool? contactlessPayment, SchemaMonetaryAmount? floorLimit, dynamic monthlyMinimumRepaymentAmount, SchemaPaymentMethodType? paymentMethodType})
- Create a new instance of SchemaPaymentCard
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- aggregateRating ↔ SchemaAggregateRating?
-
The overall rating, based on a collection of reviews or ratings, of the
item.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- annualPercentageRate ↔ dynamic
-
The annual rate that is charged for borrowing (or made by investing),
expressed as a single percentage number that represents the actual yearly
cost of funds over the term of a loan. This includes any fees or
additional costs associated with the transaction.
getter/setter pairinherited
- areaServed ↔ dynamic
-
The geographic area where a service or offered item is provided.
getter/setter pairinherited
- audience ↔ SchemaAudience?
-
An intended audience, i.e. a group for whom something was created.
getter/setter pairinherited
- availableChannel ↔ SchemaServiceChannel?
-
A means of accessing the service (e.g. a phone bank, a web site, a
location, etc.).
getter/setter pairinherited
- award ↔ String?
-
An award won by or for this item.
getter/setter pairinherited
- brand ↔ dynamic
-
The brand(s) associated with a product or service, or the brand(s)
maintained by an organization or business person.
getter/setter pairinherited
- broker ↔ dynamic
-
An entity that arranges for an exchange between a buyer and a seller. In
most cases a broker never acquires or releases ownership of a product or
service involved in an exchange. If it is not clear whether an entity is
a broker, seller, or buyer, the latter two terms are preferred.
getter/setter pairinherited
- cashBack ↔ dynamic
-
A cardholder benefit that pays the cardholder a small percentage of their
net expenditures.
getter/setter pair
- category ↔ dynamic
-
A category for the item. Greater signs or slashes can be used to
informally indicate a category hierarchy.
getter/setter pairinherited
- contactlessPayment ↔ bool?
-
A secure method for consumers to purchase products or services via debit,
credit or smartcards by using RFID or NFC technology.
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- feesAndCommissionsSpecification ↔ String?
-
Description of fees, commissions, and other terms applied either to a
class of financial product, or by a financial service organization.
getter/setter pairinherited
- floorLimit ↔ SchemaMonetaryAmount?
-
A floor limit is the amount of money above which credit card transactions
must be authorized.
getter/setter pair
- hasCertification ↔ SchemaCertification?
-
Certification information about a product, organization, service, place,
or person.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasOfferCatalog ↔ SchemaOfferCatalog?
-
Indicates an OfferCatalog listing for this Organization, Person, or
Service.
getter/setter pairinherited
- hoursAvailable ↔ SchemaOpeningHoursSpecification?
-
The hours during which this service or contact is available.
getter/setter pairinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - interestRate ↔ dynamic
-
This is different from the calculated annualPercentageRate.
getter/setter pairinherited
- isRelatedTo ↔ dynamic
-
A pointer to another, somehow related product (or multiple products).
getter/setter pairinherited
- isSimilarTo ↔ dynamic
-
A pointer to another, functionally similar product (or multiple
products).
getter/setter pairinherited
- logo ↔ dynamic
-
An associated logo.
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- monthlyMinimumRepaymentAmount ↔ dynamic
-
The minimum payment is the lowest amount of money that one is required to
pay on a credit card statement each month.
getter/setter pair
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- offers ↔ dynamic
-
An offer to provide this item—for example, an offer to sell a
product, rent the DVD of a movie, perform a service, or give away tickets
to an event. Use
SchemabusinessFunctionto indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a SchemaDemand. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.getter/setter pairinherited - owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- paymentMethodType ↔ SchemaPaymentMethodType?
-
The type of a payment method.
getter/setter pairoverride
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- produces ↔ SchemaThing?
-
The tangible thing generated by the service, e.g. a passport, permit,
etc.
getter/setter pairinherited
- provider ↔ dynamic
-
The service provider, service operator, or service performer; the goods
producer. Another party (a seller) may offer those services or goods on
behalf of the provider. A provider may also serve as the seller.
getter/setter pairinherited
- providerMobility ↔ String?
-
Indicates the mobility of a provided service (e.g. 'static', 'dynamic').
getter/setter pairinherited
- review ↔ SchemaReview?
-
A review of the item.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- serviceArea ↔ dynamic
-
The geographic area where the service is provided.
getter/setter pairinherited
- serviceAudience ↔ SchemaAudience?
-
The audience eligible for this service.
getter/setter pairinherited
- serviceOutput ↔ SchemaThing?
-
The tangible thing generated by the service, e.g. a passport, permit,
etc.
getter/setter pairinherited
- serviceType ↔ dynamic
-
The type of service being offered, e.g. veterans' benefits, emergency
relief, etc.
getter/setter pairinherited
- slogan ↔ String?
-
A slogan or motto associated with the item.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- termsOfService ↔ String?
-
Human-readable terms of service documentation.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaPaymentCard to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited