SchemaPaymentChargeSpecification class
The costs of settling the payment using a particular payment method. See https://schema.org/PaymentChargeSpecification
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaStructuredValue
- SchemaPriceSpecification
- SchemaPaymentChargeSpecification
Constructors
- SchemaPaymentChargeSpecification({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, SchemaQuantitativeValue? eligibleQuantity, SchemaPriceSpecification? eligibleTransactionVolume, dynamic identifier, dynamic image, dynamic mainEntityOfPage, num? maxPrice, dynamic membershipPointsEarned, num? minPrice, String? name, dynamic owner, SchemaAction? potentialAction, dynamic price, String? priceCurrency, String? sameAs, dynamic subjectOf, String? url, SchemaMemberProgramTier? validForMemberTier, String? validFrom, String? validThrough, bool? valueAddedTaxIncluded, SchemaDeliveryMethod? appliesToDeliveryMethod, SchemaPaymentMethod? appliesToPaymentMethod})
- Create a new instance of SchemaPaymentChargeSpecification
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- appliesToDeliveryMethod ↔ SchemaDeliveryMethod?
-
The delivery method(s) to which the delivery charge or payment charge
specification applies.
getter/setter pair
- appliesToPaymentMethod ↔ SchemaPaymentMethod?
-
The payment method(s) to which the payment charge specification applies.
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- eligibleQuantity ↔ SchemaQuantitativeValue?
-
The interval and unit of measurement of ordering quantities for which the
offer or price specification is valid. This allows e.g. specifying that a
certain freight charge is valid only for a certain quantity.
getter/setter pairinherited
- eligibleTransactionVolume ↔ SchemaPriceSpecification?
-
The transaction volume, in a monetary unit, for which the offer or price
specification is valid, e.g. for indicating a minimal purchasing volume,
to express free shipping above a certain order volume, or to limit the
acceptance of credit cards to purchases to a certain minimal amount.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- maxPrice ↔ num?
-
The highest price if the price is a range.
getter/setter pairinherited
- membershipPointsEarned ↔ dynamic
-
The number of membership points earned by the member. If necessary, the
unitText can be used to express the units the points are issued in. (E.g.
stars, miles, etc.)
getter/setter pairinherited
- minPrice ↔ num?
-
The lowest price if the price is a range.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- price ↔ dynamic
-
//www.w3.org/TR/xhtml-rdfa-primer/#using-the-content-attribute) and
Microdata syntax allow the use of a "content=" attribute for publishing
simple machine-readable values alongside more human-friendly
formatting.\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030)
to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode
symbols.
getter/setter pairinherited
- priceCurrency ↔ String?
-
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other
currency types, e.g. "Ithaca HOUR".
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
- validForMemberTier ↔ SchemaMemberProgramTier?
-
The membership program tier(s) an Offer (or a PriceSpecification,
OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid
for.
getter/setter pairinherited
- validFrom ↔ String?
-
The date when the item becomes valid.
getter/setter pairinherited
- validThrough ↔ String?
-
The date after when the item is not valid. For example the end of an
offer, salary period, or a period of opening hours.
getter/setter pairinherited
- valueAddedTaxIncluded ↔ bool?
-
Specifies whether the applicable value-added tax (VAT) is included in the
price specification or not.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaPaymentChargeSpecification to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited