SchemaPhysicalActivity class
Any bodily activity that enhances or maintains physical fitness and overall health and wellness. Includes activity that is part of daily living and routine, structured exercise, and exercise prescribed as part of a medical treatment or recovery plan. See https://schema.org/PhysicalActivity
- Inheritance
-
- Object
- SchemaThing
- SchemaMedicalEntity
- SchemaLifestyleModification
- SchemaPhysicalActivity
- Implementers
Constructors
- SchemaPhysicalActivity({String? additionalType, String? alternateName, SchemaMedicalCode? code, dynamic description, String? disambiguatingDescription, SchemaGrant? funding, SchemaMedicalGuideline? guideline, dynamic identifier, dynamic image, dynamic legalStatus, dynamic mainEntityOfPage, SchemaMedicineSystem? medicineSystem, String? name, dynamic owner, SchemaAction? potentialAction, SchemaOrganization? recognizingAuthority, SchemaMedicalSpecialty? relevantSpecialty, String? sameAs, SchemaMedicalStudy? study, dynamic subjectOf, String? url, dynamic associatedAnatomy, dynamic category, String? epidemiology, String? pathophysiology})
- Create a new instance of SchemaPhysicalActivity
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- associatedAnatomy ↔ dynamic
-
The anatomy of the underlying organ system or structures associated with
this entity.
getter/setter pair
- category ↔ dynamic
-
A category for the item. Greater signs or slashes can be used to
informally indicate a category hierarchy.
getter/setter pair
- code ↔ SchemaMedicalCode?
-
A medical code for the entity, taken from a controlled vocabulary or
ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- epidemiology ↔ String?
-
The characteristics of associated patients, such as age, gender, race
etc.
getter/setter pair
- funding ↔ SchemaGrant?
-
A SchemaGrant that directly or indirectly provide funding or
sponsorship for this item. See also
SchemaownershipFundingInfo.getter/setter pairinherited - guideline ↔ SchemaMedicalGuideline?
-
A medical guideline related to this entity.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - legalStatus ↔ dynamic
-
The drug or supplement's legal status, including any controlled substance
schedules that apply.
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- medicineSystem ↔ SchemaMedicineSystem?
-
The system of medicine that includes this MedicalEntity, for example
'evidence-based', 'homeopathic', 'chiropractic', etc.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- pathophysiology ↔ String?
-
Changes in the normal mechanical, physical, and biochemical functions
that are associated with this activity or condition.
getter/setter pair
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- recognizingAuthority ↔ SchemaOrganization?
-
If applicable, the organization that officially recognizes this entity as
part of its endorsed system of medicine.
getter/setter pairinherited
- relevantSpecialty ↔ SchemaMedicalSpecialty?
-
If applicable, a medical specialty in which this entity is relevant.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- study ↔ SchemaMedicalStudy?
-
A medical study or trial related to this entity.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaPhysicalActivity to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited