SchemaPostalAddress class
The mailing address. See https://schema.org/PostalAddress
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaStructuredValue
- SchemaContactPoint
- SchemaPostalAddress
Constructors
- SchemaPostalAddress({String? additionalType, String? alternateName, dynamic areaServed, dynamic availableLanguage, SchemaContactPointOption? contactOption, String? contactType, dynamic description, String? disambiguatingDescription, String? email, String? faxNumber, SchemaOpeningHoursSpecification? hoursAvailable, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, dynamic productSupported, String? sameAs, dynamic serviceArea, dynamic subjectOf, String? telephone, String? url, dynamic addressCountry, String? addressLocality, dynamic addressRegion, String? extendedAddress, String? postOfficeBoxNumber, String? postalCode, String? streetAddress})
- Create a new instance of SchemaPostalAddress
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- addressCountry ↔ dynamic
-
//en.wikipedia.org/wiki/ISO_3166-1_alpha-3) country code such as "SGP" or
a full country name such as "Singapore" can also be used.
getter/setter pair
- addressLocality ↔ String?
-
The locality in which the street address is, and which is in the region.
For example, Mountain View.
getter/setter pair
- addressRegion ↔ dynamic
-
//en.wikipedia.org/wiki/List_of_administrative_divisions_by_country) such
as the Province in Italy or Region in Germany.
getter/setter pair
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- areaServed ↔ dynamic
-
The geographic area where a service or offered item is provided.
getter/setter pairinherited
- availableLanguage ↔ dynamic
-
//tools.ietf.org/html/bcp47). See also
SchemainLanguage.getter/setter pairinherited - contactOption ↔ SchemaContactPointOption?
-
An option available on this contact point (e.g. a toll-free number or
support for hearing-impaired callers).
getter/setter pairinherited
- contactType ↔ String?
-
A person or organization can have different contact points, for different
purposes. For example, a sales contact point, a PR contact point and so
on. This property is used to specify the kind of contact point.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- email ↔ String?
-
Email address.
getter/setter pairinherited
- extendedAddress ↔ String?
-
An address extension such as an apartment number, C/O or alternative
name.
getter/setter pair
- faxNumber ↔ String?
-
The fax number.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoursAvailable ↔ SchemaOpeningHoursSpecification?
-
The hours during which this service or contact is available.
getter/setter pairinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- postalCode ↔ String?
-
The postal code. For example, 94043.
getter/setter pair
- postOfficeBoxNumber ↔ String?
-
The post office box number for PO box addresses.
getter/setter pair
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- productSupported ↔ dynamic
-
The product or service this support contact point is related to (such as
product support for a particular product line). This can be a specific
product or product line (e.g. "iPhone") or a general category of products
or services (e.g. "smartphones").
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- serviceArea ↔ dynamic
-
The geographic area where the service is provided.
getter/setter pairinherited
- streetAddress ↔ String?
-
The street address. For example, 1600 Amphitheatre Pkwy.
getter/setter pair
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- telephone ↔ String?
-
The telephone number.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaPostalAddress to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited