SchemaResidence class
The place where a person lives. See https://schema.org/Residence
- Inheritance
-
- Object
- SchemaThing
- SchemaPlace
- SchemaResidence
- Implementers
Constructors
- SchemaResidence({SchemaPropertyValue? additionalProperty, String? additionalType, dynamic address, SchemaAggregateRating? aggregateRating, String? alternateName, SchemaLocationFeatureSpecification? amenityFeature, String? branchCode, SchemaPlace? containedIn, SchemaPlace? containedInPlace, SchemaPlace? containsPlace, dynamic description, String? disambiguatingDescription, SchemaEvent? event, SchemaEvent? events, String? faxNumber, dynamic geo, dynamic geoContains, dynamic geoCoveredBy, dynamic geoCovers, dynamic geoCrosses, dynamic geoDisjoint, dynamic geoEquals, dynamic geoIntersects, dynamic geoOverlaps, dynamic geoTouches, dynamic geoWithin, String? globalLocationNumber, SchemaCertification? hasCertification, bool? hasDriveThroughService, String? hasGS1DigitalLink, dynamic hasMap, dynamic identifier, dynamic image, bool? isAccessibleForFree, String? isicV4, dynamic keywords, dynamic latitude, dynamic logo, dynamic longitude, dynamic mainEntityOfPage, String? map, String? maps, int? maximumAttendeeCapacity, String? name, SchemaOpeningHoursSpecification? openingHoursSpecification, dynamic owner, dynamic photo, dynamic photos, SchemaAction? potentialAction, bool? publicAccess, SchemaReview? review, SchemaReview? reviews, String? sameAs, String? slogan, bool? smokingAllowed, SchemaOpeningHoursSpecification? specialOpeningHoursSpecification, dynamic subjectOf, String? telephone, String? tourBookingPage, String? url, SchemaFloorPlan? accommodationFloorPlan, String? floorLevel})
- Create a new instance of SchemaResidence
Properties
- accommodationFloorPlan ↔ SchemaFloorPlan?
-
A floorplan of some SchemaAccommodation.
getter/setter pair
- additionalProperty ↔ SchemaPropertyValue?
-
//schema.org/gtin13, ...) will typically expect such data to be provided
using those properties, rather than using the generic property/value
mechanism.
getter/setter pairinherited
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- address ↔ dynamic
-
Physical address of the item.
getter/setter pairinherited
- aggregateRating ↔ SchemaAggregateRating?
-
The overall rating, based on a collection of reviews or ratings, of the
item.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- amenityFeature ↔ SchemaLocationFeatureSpecification?
-
An amenity feature (e.g. a characteristic or service) of the
Accommodation. This generic property does not make a statement about
whether the feature is included in an offer for the main accommodation or
available at extra costs.
getter/setter pairinherited
- branchCode ↔ String?
-
//www.starbucks.co.uk/store-locator/etc/detail/3047 the code "3047" is a
branchCode for a particular branch.
getter/setter pairinherited
- containedIn ↔ SchemaPlace?
-
The basic containment relation between a place and one that contains it.
getter/setter pairinherited
- containedInPlace ↔ SchemaPlace?
-
The basic containment relation between a place and one that contains it.
getter/setter pairinherited
- containsPlace ↔ SchemaPlace?
-
The basic containment relation between a place and another that it
contains.
getter/setter pairinherited
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- event ↔ SchemaEvent?
-
Upcoming or past event associated with this place, organization, or
action.
getter/setter pairinherited
- events ↔ SchemaEvent?
-
Upcoming or past events associated with this place or organization.
getter/setter pairinherited
- faxNumber ↔ String?
-
The fax number.
getter/setter pairinherited
- floorLevel ↔ String?
-
//en.wikipedia.org/wiki/Storey#Consecutive_number_floor_designations),
the local system should be used where possible.
getter/setter pair
- geo ↔ dynamic
-
The geo coordinates of the place.
getter/setter pairinherited
- geoContains ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoCoveredBy ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoCovers ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoCrosses ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoDisjoint ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).)
getter/setter pairinherited
- geoEquals ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM). "Two geometries are topologically equal
if their interiors intersect and no part of the interior or boundary of
one geometry intersects the exterior of the other" (a symmetric
relationship).
getter/setter pairinherited
- geoIntersects ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoOverlaps ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- geoTouches ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).)
getter/setter pairinherited
- geoWithin ↔ dynamic
-
//en.wikipedia.org/wiki/DE-9IM).
getter/setter pairinherited
- globalLocationNumber ↔ String?
-
//www.gs1.org/gln) (GLN, sometimes also referred to as International
Location Number or ILN) of the respective organization, person, or place.
The GLN is a 13-digit number used to identify parties and physical
locations.
getter/setter pairinherited
- hasCertification ↔ SchemaCertification?
-
Certification information about a product, organization, service, place,
or person.
getter/setter pairinherited
- hasDriveThroughService ↔ bool?
-
Indicates whether some facility (e.g. SchemaFoodEstablishment,
SchemaCovidTestingFacility) offers a service that can be used by
driving through in a car. In the case of SchemaCovidTestingFacility
such facilities could potentially help with social distancing from other
potentially-infected users.
getter/setter pairinherited
- hasGS1DigitalLink ↔ String?
-
- A Digital Link that contains a serial number (AI
21) should only be present on instances of [SchemaIndividualProduct]- A Digital Link that contains a lot number (AI
10) should be annotated as [SchemaSomeProducts] if only products from that lot are sold, or [SchemaIndividualProduct] if there is only a specific product.- A Digital Link that contains a global model number (AI
8013) should be attached to a [SchemaProduct] or a [SchemaProductModel].getter/setter pairinherited - A Digital Link that contains a serial number (AI
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMap ↔ dynamic
-
A URL to a map of the place.
getter/setter pairinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - isAccessibleForFree ↔ bool?
-
A flag to signal that the item, event, or place is accessible for free.
getter/setter pairinherited
- isicV4 ↔ String?
-
The International Standard of Industrial Classification of All Economic
Activities (ISIC), Revision 4 code for a particular organization,
business person, or place.
getter/setter pairinherited
- keywords ↔ dynamic
-
Keywords or tags used to describe some item. Multiple textual entries in
a keywords list are typically delimited by commas, or by repeating the
property.
getter/setter pairinherited
- latitude ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)).
getter/setter pairinherited
- logo ↔ dynamic
-
An associated logo.
getter/setter pairinherited
- longitude ↔ dynamic
-
//en.wikipedia.org/wiki/World_Geodetic_System)).
getter/setter pairinherited
- mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- map ↔ String?
-
A URL to a map of the place.
getter/setter pairinherited
- maps ↔ String?
-
A URL to a map of the place.
getter/setter pairinherited
- maximumAttendeeCapacity ↔ int?
-
The total number of individuals that may attend an event or venue.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- openingHoursSpecification ↔ SchemaOpeningHoursSpecification?
-
The opening hours of a certain place.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- photo ↔ dynamic
-
A photograph of this place.
getter/setter pairinherited
- photos ↔ dynamic
-
Photographs of this place.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- publicAccess ↔ bool?
-
A flag to signal that the SchemaPlace is open to public visitors. If
this property is omitted there is no assumed default boolean value.
getter/setter pairinherited
- review ↔ SchemaReview?
-
A review of the item.
getter/setter pairinherited
- reviews ↔ SchemaReview?
-
Review of the item.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- slogan ↔ String?
-
A slogan or motto associated with the item.
getter/setter pairinherited
- smokingAllowed ↔ bool?
-
Indicates whether it is allowed to smoke in the place, e.g. in the
restaurant, hotel or hotel room.
getter/setter pairinherited
- specialOpeningHoursSpecification ↔ SchemaOpeningHoursSpecification?
-
The special opening hours of a certain place.\n\nUse this to explicitly
override general opening hours brought in scope by
SchemaopeningHoursSpecificationorSchemaopeningHours.getter/setter pairinherited - subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- telephone ↔ String?
-
The telephone number.
getter/setter pairinherited
- tourBookingPage ↔ String?
-
A page providing information on how to book a tour of some SchemaPlace,
such as an SchemaAccommodation or SchemaApartmentComplex in a real
estate setting, as well as other kinds of tours as appropriate.
getter/setter pairinherited
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaResidence to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited