SchemaShippingDeliveryTime class
ShippingDeliveryTime provides various pieces of information about delivery times for shipping. See https://schema.org/ShippingDeliveryTime
- Inheritance
-
- Object
- SchemaThing
- SchemaIntangible
- SchemaStructuredValue
- SchemaShippingDeliveryTime
Constructors
- SchemaShippingDeliveryTime({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, dynamic businessDays, String? cutoffTime, dynamic handlingTime, dynamic transitTime})
- Create a new instance of SchemaShippingDeliveryTime
Properties
- additionalType ↔ String?
-
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
- alternateName ↔ String?
-
An alias for the item.
getter/setter pairinherited
- businessDays ↔ dynamic
-
Days of the week when the merchant typically operates, indicated via
opening hours markup.
getter/setter pair
- cutoffTime ↔ String?
-
30 pm Eastern Standard Time (EST) which is 5 hours behind Coordinated
Universal Time (UTC).
getter/setter pair
- description ↔ dynamic
-
A description of the item.
getter/setter pairinherited
- disambiguatingDescription ↔ String?
-
A sub property of description. A short description of the item used to
disambiguate from other, similar items. Information from other properties
(in particular, name) may be necessary for the description to be useful
for disambiguation.
getter/setter pairinherited
- handlingTime ↔ dynamic
-
minValue, maxValue, unitCode (d for DAY). This is by common convention
assumed to mean business days (if a unitCode is used, coded as "d"), i.e.
only counting days when the business normally operates.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ dynamic
-
The identifier property represents any kind of identifier for any kind of
SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides
dedicated properties for representing many of these, either as textual
strings or as URL (URI) links. See background
notes for more details.
getter/setter pairinherited
- image ↔ dynamic
-
An image of the item. This can be a
SchemaURLor a fully described SchemaImageObject.getter/setter pairinherited - mainEntityOfPage ↔ dynamic
-
Indicates a page (or other CreativeWork) for which this thing is the main
entity being described. See background
notes for details.
getter/setter pairinherited
- name ↔ String?
-
The name of the item.
getter/setter pairinherited
- owner ↔ dynamic
-
A person or organization who owns this Thing.
getter/setter pairinherited
- potentialAction ↔ SchemaAction?
-
Indicates a potential Action, which describes an idealized action in
which this thing would play an 'object' role.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sameAs ↔ String?
-
URL of a reference Web page that unambiguously indicates the item's
identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or
official website.
getter/setter pairinherited
- subjectOf ↔ dynamic
-
A CreativeWork or Event about this Thing.
getter/setter pairinherited
- transitTime ↔ dynamic
-
minValue, maxValue, unitCode (d for DAY).
getter/setter pair
- url ↔ String?
-
URL of the item.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonLd(
) → Map< String, dynamic> -
Serialize SchemaShippingDeliveryTime to JSON-LD
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited