SchemaTicket class

Used to describe a ticket to an event, a flight, a bus ride, etc. See https://schema.org/Ticket

Inheritance

Constructors

SchemaTicket({String? additionalType, String? alternateName, dynamic description, String? disambiguatingDescription, dynamic identifier, dynamic image, dynamic mainEntityOfPage, String? name, dynamic owner, SchemaAction? potentialAction, String? sameAs, dynamic subjectOf, String? url, String? dateIssued, SchemaOrganization? issuedBy, String? priceCurrency, String? ticketNumber, String? ticketToken, SchemaSeat? ticketedSeat, dynamic totalPrice, dynamic underName})
Create a new instance of SchemaTicket

Properties

additionalType String?
//schema.org/docs/styleguide.html">style guide.
getter/setter pairinherited
alternateName String?
An alias for the item.
getter/setter pairinherited
dateIssued String?
The date the ticket was issued.
getter/setter pair
description ↔ dynamic
A description of the item.
getter/setter pairinherited
disambiguatingDescription String?
A sub property of description. A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
identifier ↔ dynamic
The identifier property represents any kind of identifier for any kind of SchemaThing, such as ISBNs, GTIN codes, UUIDs etc. Schema.org provides dedicated properties for representing many of these, either as textual strings or as URL (URI) links. See background notes for more details.
getter/setter pairinherited
image ↔ dynamic
An image of the item. This can be a SchemaURL or a fully described SchemaImageObject.
getter/setter pairinherited
issuedBy SchemaOrganization?
The organization issuing the item, for example a SchemaPermit, SchemaTicket, or SchemaCertification.
getter/setter pair
mainEntityOfPage ↔ dynamic
Indicates a page (or other CreativeWork) for which this thing is the main entity being described. See background notes for details.
getter/setter pairinherited
name String?
The name of the item.
getter/setter pairinherited
owner ↔ dynamic
A person or organization who owns this Thing.
getter/setter pairinherited
potentialAction SchemaAction?
Indicates a potential Action, which describes an idealized action in which this thing would play an 'object' role.
getter/setter pairinherited
priceCurrency String?
//en.wikipedia.org/wiki/Local_exchange_trading_system) (LETS) and other currency types, e.g. "Ithaca HOUR".
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sameAs String?
URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Wikidata entry, or official website.
getter/setter pairinherited
subjectOf ↔ dynamic
A CreativeWork or Event about this Thing.
getter/setter pairinherited
ticketedSeat SchemaSeat?
The seat associated with the ticket.
getter/setter pair
ticketNumber String?
The unique identifier for the ticket.
getter/setter pair
ticketToken String?
Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.
getter/setter pair
totalPrice ↔ dynamic
\n\n* Use values from 0123456789 (Unicode 'DIGIT ZERO' (U+0030) to 'DIGIT NINE' (U+0039)) rather than superficially similar Unicode symbols.\n* Use '.' (Unicode 'FULL STOP' (U+002E)) rather than ',' to indicate a decimal point. Avoid using these symbols as a readability separator.
getter/setter pair
underName ↔ dynamic
The person or organization the reservation or ticket is for.
getter/setter pair
url String?
URL of the item.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonLd() Map<String, dynamic>
Serialize SchemaTicket to JSON-LD
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited